@@ -335,10 +335,6 @@ void defineworld(x1, y1, x2, y2, mapx, mapy)
 	dyg = yg2 - yg1;
 	break;
     }
-    if (debuglevel == 3) {
-	printf("%f %f %f %f\n", x1, x2, y1, y2);
-	printf("%f %f %f %f\n", xg1, xg2, yg1, yg2);
-    }
 }
 
 /*
@@ -1066,6 +1062,11 @@ int n;
 	my_draw2((x[i]+x[i-1])/2, y[i]);
 	my_draw2((x[i]+x[i+1])/2, y[i]);
     }
+    if (i < n)
+    {
+	my_draw2((x[i] + x[i-1])/2, y[i]);
+	my_draw2(x[i], y[i]);
+    }
 }
 
 /*
