@@ -5,8 +5,14 @@
 
 #include <stdio.h>
 #include <math.h>
+#include <string.h>
 #include "globals.h"
 #include "externs.h"
+#include "alerts.h"
+#include "chersh.h"
+#include "draw.h"
+#include "events.h"
+#include "graphutils.h"
 
 extern double devcharsize;
 double setcharsize();
@@ -55,7 +61,6 @@ void undrawaxes(gno)
 {
     int i;
     int tmp_color, tmp_color2;
-    extern int bgcolor;
 
     for (i = 0; i < 6; i++) {
 	  if (g[gno].t[i].active == ON) {
@@ -216,23 +221,21 @@ void create_ticklabel(form, prec, loc, s)
     char *s;
 {
     char format[256];
-    char tmpbuf[256];
     double tmp;
-    int m, d, y, h, mm;
+    int m, /* d,*/ y /*, h, mm*/;
     double sec;
-    int isign = 0;
 /*    extern char *months[];
     extern char *monthl[];
     extern char *dayofweekstrs[];
     extern char *dayofweekstrl[]; */
 
-    strcpy(format, "%.*lf");
+    strcpy(format, "%.*f");
     switch (form) {
     case DECIMAL:
 	sprintf(s, format, prec, loc);
 	tmp = atof(s);		/* fix reverse axes problem when loc == -0.0 */
 	if (tmp == 0.0) {
-	    strcpy(format, "%.*lf");
+	    strcpy(format, "%.*f");
 	    loc = 0.0;
 	    sprintf(s, format, prec, loc);
 	}
@@ -249,14 +252,13 @@ void create_ticklabel(form, prec, loc, s)
 	break;
     case POWER:
 	if (loc < 0.0) {
-	    isign = 1;
 	    loc = log10(-loc);
-	    strcpy(format, "-10\\S%.*lf\\N");
+	    strcpy(format, "-10\\S%.*f\\N");
 	} else if (loc == 0.0) {
-	    sprintf(format, "%.*lf", prec, 0.0);
+	    sprintf(format, "%.*f", prec, 0.0);
 	} else {
 	    loc = log10(loc);
-	    strcpy(format, "10\\S%.*lf\\N");
+	    strcpy(format, "10\\S%.*f\\N");
 	}
 	sprintf(s, format, prec, loc);
 	break;
@@ -273,9 +275,9 @@ void create_ticklabel(form, prec, loc, s)
         case DEGREESLON:
 	if (loc < 0.0) {
 	    loc *= -1.0;
-	    strcpy(format, "%.*lfW");
+	    strcpy(format, "%.*fW");
 	} else if (loc > 0.0) {
-	    strcpy(format, "%.*lfE");
+	    strcpy(format, "%.*fE");
 	} else {
 	    strcpy(format, "0");
 	}
@@ -284,9 +286,9 @@ void create_ticklabel(form, prec, loc, s)
     case DEGREESMMLON:
 	if (loc < 0.0) {
 	    loc *= -1.0;
-	    strcpy(format, "%d %.*lf' W");
+	    strcpy(format, "%d %.*f' W");
 	} else if (loc > 0.0) {
-	    strcpy(format, "%d %.*lf' E");
+	    strcpy(format, "%d %.*f' E");
 	} else {
 	    strcpy(format, "0 0'");
 	}
@@ -297,9 +299,9 @@ void create_ticklabel(form, prec, loc, s)
     case DEGREESMMSSLON:
 	if (loc < 0.0) {
 	    loc *= -1.0;
-	    strcpy(format, "%d %d' %.*lf\" W");
+	    strcpy(format, "%d %d' %.*f\" W");
 	} else if (loc > 0.0) {
-	    strcpy(format, "%d %d' %.*lf\" E");
+	    strcpy(format, "%d %d' %.*f\" E");
 	} else {
 	    strcpy(format, "0 0' 0\"");
 	}
@@ -314,9 +316,9 @@ void create_ticklabel(form, prec, loc, s)
     case DEGREESLAT:
 	if (loc < 0.0) {
 	    loc *= -1.0;
-	    strcpy(format, "%.*lfS");
+	    strcpy(format, "%.*fS");
 	} else if (loc > 0.0) {
-	    strcpy(format, "%.*lfN");
+	    strcpy(format, "%.*fN");
 	} else {
 	    strcpy(format, "0");
 	}
@@ -325,9 +327,9 @@ void create_ticklabel(form, prec, loc, s)
     case DEGREESMMLAT:
 	if (loc < 0.0) {
 	    loc *= -1.0;
-	    strcpy(format, "%d %.*lf' S");
+	    strcpy(format, "%d %.*f' S");
 	} else if (loc > 0.0) {
-	    strcpy(format, "%d %.*lf' N");
+	    strcpy(format, "%d %.*f' N");
 	} else {
 	    strcpy(format, "0 0'");
 	}
@@ -338,9 +340,9 @@ void create_ticklabel(form, prec, loc, s)
     case DEGREESMMSSLAT:
 	if (loc < 0.0) {
 	    loc *= -1.0;
-	    strcpy(format, "%d %d' %.*lf\" S");
+	    strcpy(format, "%d %d' %.*f\" S");
 	} else if (loc > 0.0) {
-	    strcpy(format, "%d %d' %.*lf\" N");
+	    strcpy(format, "%d %d' %.*f\" N");
 	} else {
 	    strcpy(format, "0 0' 0\"");
 	}
@@ -365,7 +367,7 @@ void drawxticklabels(gno, caxis)
     world w;
     view v;
     char s[256];
-    double loc, x, y, top, bot;
+    double loc, x /*, y*/, top, bot;
     int i = 0, ifudge, iy, nticks, bjust = 2, tjust = 2;
     int tang;
     double delb = 0.0, delt = 0.0, vyb, vyt, vx, ofx, ofb, oft;
@@ -587,7 +589,7 @@ void drawyticklabels(gno, caxis)
     world w;
     view v;
     char s[256];
-    double loc, x, y, top, bot;
+    double loc /*, x*/, y, top, bot;
     int i = 0, ifudge, ix, nticks;
     int ljust = 1, rjust = 0;
     int tang, ylabpos = 0;
