@@ -8,10 +8,7 @@
 #include <math.h>
 
 #include <X11/X.h>
-#include <X11/Xatom.h>
 #include <X11/Intrinsic.h>
-#include <X11/Shell.h>
-#include <X11/keysym.h>
 
 #ifdef XVIEW
 #include <X11/Xlib.h>
@@ -19,13 +16,11 @@
 #include <xview/frame.h>
 #include <xview/canvas.h>
 #include <xview/panel.h>
-#include <xview/cursor.h>
 
 
 /*
  * items for the most part on the main panel declared in xvgr.c
  */
-extern Frame main_frame;
 extern Panel_item legend_x_panel, legend_y_panel; 	/* from symwin.c */
 /* extern Panel_item timestamp_x_item, timestamp_y_item; */	/* from pagewin.c */
 extern Canvas canvas;
@@ -59,12 +54,33 @@ static Arg al;
 
 #endif
 
+#include "globals.h"
+#include "alerts.h"
+#include "checkon.h"
+#include "chersh.h"
+#include "compwin1.h"
+#include "draw.h"
+#include "events.h"
+#include "drawticks.h"
+#include "fileswin.h"
+#include "graphutils.h"
+#include "graphutils2.h"
+#include "io.h"
+#include "labelwin.h"
+#include "main.h"
+#include "objutils.h"
+#include "plotone.h"
+#include "setutils.h"
+#include "symwin.h"
+#include "tickwin.h"
+#include "utils.h"
+#include "worldwin.h"
+#include "xvlib.h"
+
 /* TODO this doesn't belong here */
 int cursortype = 0;
 static int cursor_oldx = -1, cursor_oldy = -1;
 
-/* for pointer based set operations */
-static int setno1, setno2, graphno1, graphno2, loc1, loc2;
 
 /*
  * conversion from world to viewport coords defined in draw.c
@@ -75,7 +91,6 @@ void motion();
 void select_line();
 void select_region();
 
-#include "globals.h"
 /* things that should be moved to at some stage */
 #define EXPAND_1ST 61
 #define EXPAND_2ND 62
@@ -121,8 +136,6 @@ static int sx, sy;
 static int old_x, old_y;
 static int xs, ys;
 static int action_flag = 0;
-static int setindex = 0;
-static int setnumber = 0;
 
 /*
  * variables for the text handling routine
@@ -140,18 +153,14 @@ static double co = 1.0;
 int tag1, tag2;
 int *fit_array, nos_fit_tags;
 void (*update_tags_func)();
+int define_tag_string();
+
 
 /*
  * added by sjah
  *
  */
 int track_point = 0; /* moved from definition in ptswin.c */
-extern void draw_tmp_tag();
-extern int get_chan_content();
-extern int set_tag_ok();
-extern int define_tag_line();
-extern int define_tag_string();
-extern void clear_graph_viewport();
 
 /*
  * draw all active graphs, when graphs are drawn, draw the focus markers
@@ -470,9 +479,6 @@ void refresh(c, w, repaint_area)
     Xv_Window w;
     Rectlist *repaint_area;
 {
-    extern int bc;		/* for X11R4 servers w/XView 2.0 */
-    extern char batchfile[];
-
     win_h = (int) xv_get(w, XV_HEIGHT);
     win_w = (int) xv_get(w, XV_WIDTH);
     if (debuglevel == 6) {
@@ -531,7 +537,7 @@ void my_resize_proc(c, w, h)
 	printf("In my_resize_proc() %d %d %d\n", win_w, win_h, inwin);
     }
     if (redraw_now && redraw_now == called) {
-	refresh(c, canvas_paint_window(c), NULL);
+	refresh(c, canvas_paint_window(c), (Rectlist *) NULL);
     } else if (inwin) {
 	if (backingstore) {
 	    resize_backpix();
@@ -571,14 +577,13 @@ void getpoints(x, y)
     double dsx = 0.0, dsy = 0.0;
     int newg;
     char buf[256];
-    extern char locator_format[];
 
 #ifdef XVIEW
     if (!inwin) {
 	if (debuglevel == 6) {
 	    printf("inwin == FALSE in getpoints(), doing a drawgraph2(-1)\n");
 	}
-	refresh(canvas, paint_window, NULL);
+	refresh(canvas, paint_window, (Rectlist *) NULL);
     }
 #endif
 
@@ -749,7 +754,6 @@ void set_action(act)
     int act;
 {
     defaults d;
-    char tmpbuf[128];
 
     get_graph_defaults(cg, &d);
 
@@ -958,7 +962,7 @@ void my_proc(window, xv_event)
     switch (event->type) {
     case KeyPress:
 	buf[0] = 0;
-	XLookupString(event, buf, 1, &keys, &compose);
+	XLookupString(&(event->xkey), buf, 1, &keys, &compose);
 	switch (c = buf[0]) {
 	case 1:		/* ^A */
 	    if (activeset(cg)) {
@@ -1090,16 +1094,15 @@ void my_proc(window, xv_event)
 	    getpoints(x, y);
 	    go_locateflag = c;
 	    {
-		if (!action_flag && allow_dc && double_click(event)) {
+		if (!action_flag && allow_dc &&
+		    double_click(&(event->xbutton))) {
 		    if (tmpcg == cg) {	/* don't allow a change of focus */
-			int setno, loc, soft;
-			/* extern */ int cset = 0; 
+			int setno, loc;
 
 			device2world(x, y, &wx, &wy);
 			if (symok(wx, wy)) {
 			    findpoint(cg, wx, wy, &wx, &wy, &setno, &loc);
 			    if (setno != -1) {
-				cset = setno;
 				set_wait_cursor(NULL);
 				set_right_footer("Opening View/Symbols...");
 				define_symbols_popup(); 
@@ -1511,7 +1514,7 @@ void my_proc(window, xv_event)
  */
 	    case DEACTIVATE_NEAREST:
 		{
-		    int setno, loc, soft;
+		    int setno, loc;
 
 		    device2world(x, y, &wx, &wy);
 		    findpoint(cg, wx, wy, &wx, &wy, &setno, &loc);
@@ -1544,7 +1547,7 @@ void my_proc(window, xv_event)
 		    device2world(x, y, &wx, &wy);
 		    findpoint(cg, wx, wy, &wx, &wy, &setno, &loc);
 		    if (setno != -1) {
-			sprintf(buf, "Set %d, loc %d, (%lf, %lf)", setno, loc, wx, wy);
+			sprintf(buf, "Set %d, loc %d, (%f, %f)", setno, loc, wx, wy);
 /*			xv_setstr(locate_point_item, buf); */
 			set_action(FIND_POINT);
 		    } else {
@@ -1558,7 +1561,6 @@ void my_proc(window, xv_event)
  */
 	    case TRACKER:
 		{
-		    extern int track_set, track_point;
 		    int xtmp, ytmp;
 		    double *xx, *yy;
 
@@ -1576,10 +1578,10 @@ void my_proc(window, xv_event)
 			if (inbounds(cg, xx[track_point], yy[track_point])) {
 			    world2deviceabs(xx[track_point], yy[track_point], &xtmp, &ytmp);
 			    setpointer(xtmp, ytmp);
-			    sprintf(buf, "Set %d, loc %d, (%lf, %lf)", track_set, track_point + 1,
+			    sprintf(buf, "Set %d, loc %d, (%f, %f)", track_set, track_point + 1,
 				    xx[track_point], yy[track_point]);
 			} else {
-			    sprintf(buf, "OUTSIDE - Set %d, loc %d, (%lf, %lf)", track_set, track_point + 1,
+			    sprintf(buf, "OUTSIDE - Set %d, loc %d, (%f, %f)", track_set, track_point + 1,
 				    xx[track_point], yy[track_point]);
 			}
 /*			xv_setstr(locate_point_item, buf); */
@@ -1633,7 +1635,6 @@ void my_proc(window, xv_event)
 		set_action(0);
 		draw_tmp_tag(cg,x,y);
 		{
-		      extern void default_ticks();
 		      world w;
 		      get_graph_world(cg,&w);
 		      device2world(x, y, &wx1, &wy1);
@@ -1729,7 +1730,7 @@ void my_proc(window, xv_event)
 		    double *x = getx(cg, track_set), *y = gety(cg, track_set);
 
 		    if (track_set == -1) {
-			device2world(x, y, &wx, &wy);
+			device2world((int) *x, (int) *y, &wx, &wy);
 			findpoint(cg, wx, wy, &wx, &wy, &track_set, &track_point);
 			track_point--;
 			if (track_point < 0) {
@@ -1740,10 +1741,10 @@ void my_proc(window, xv_event)
 			if (inbounds(cg, x[track_point], y[track_point])) {
 			    world2deviceabs(x[track_point], y[track_point], &xtmp, &ytmp);
 			    setpointer(xtmp, ytmp);
-			    sprintf(buf, "Set %d, loc %d, (%lf, %lf)", track_set, track_point + 1,
+			    sprintf(buf, "Set %d, loc %d, (%f, %f)", track_set, track_point + 1,
 				    x[track_point], y[track_point]);
 			} else {
-			    sprintf(buf, "OUTSIDE - Set %d, loc %d, (%lf, %lf)", track_set, track_point + 1,
+			    sprintf(buf, "OUTSIDE - Set %d, loc %d, (%f, %f)", track_set, track_point + 1,
 				    x[track_point], y[track_point]);
 			}
 /*			xv_setstr(locate_point_item, buf); */
@@ -1767,7 +1768,7 @@ void my_proc(window, xv_event)
 	y = event->xmotion.y;
 /* experimental - cross hair cursor function defined at the bottom of this file */
 	if (cursortype) {
-	    motion(event);
+	    motion(&(event->xmotion));
 	}
 /* experimental - allows painting of points */
 	if (event->xmotion.state & Button1MotionMask) {
@@ -1786,8 +1787,8 @@ void my_proc(window, xv_event)
 		    if (add_setno >= 0) {
 			if (paint_skip == 0 || (count % paint_skip == 0)) {
 			    ind = getsetlength(cg, add_setno);
-			    add_point(cg, add_setno, wx, wy, 0.0, 0.0, XY);
-			    sprintf(buf, "Set %d, loc %d, (%lf, %lf)", add_setno, ind + 1, wx, wy);
+			    add_point(cg, add_setno, wx, wy, XY);
+			    sprintf(buf, "Set %d, loc %d, (%f, %f)", add_setno, ind + 1, wx, wy);
 /*			    xv_setstr(locate_point_item, buf); */
 			    XDrawLine(disp, xwin, gc, x - 5, y - 5, x + 5, y + 5);
 			    XDrawLine(disp, xwin, gc, x - 5, y + 5, x + 5, y - 5);
@@ -1905,6 +1906,7 @@ int double_click(e)
     return 0;
 }
 
+/*ARGSUSED*/
 void
 draw_tmp_tag(gno,x,y)
       int   gno;
