@@ -54,10 +54,8 @@ static Panel_item files_cbox_item;
  * Event and Notify proc declarations
  */
 static int files_Done_notify_proc();
-static void files_type_notify_proc();
 static void files_list_notify_proc();
 static Panel_setting files_file_notify_proc();
-static void files_graph_notify_proc();
 static int files_accept_notify_proc();
 static void update_files();
 
@@ -316,7 +314,6 @@ static Panel_setting files_file_notify_proc(item, event)
 }
 
 static char filesfname[MAXPATHLEN];
-static int readtograph;
 int spec_type;  /* carry information to files.c about whether this is a spectrum */
 
 /*ARGSUSED*/
@@ -498,7 +495,7 @@ sort_sigusr1_handler(client,sig,mode)
 		}
 	    }
 
-	    /* do the reading of the data an display it (hopefully) */
+	    /* do the reading of the data and display it (hopefully) */
 	    if (spec_type == SORT_NEW_SPEC && autoscale_onread) {
 		  defaultgraph(graphno);
 		  default_axis(graphno,SPEC,X_AXIS);
@@ -548,7 +545,8 @@ sort_sigusr1_handler(client,sig,mode)
 		} while(stat(papf, &stto) == 0);
 
 		if ((fp = fopen(papf, "w")) == NULL)
-		    fprintf(stderr, "Unable to create file for paper, you're on your own.\n");
+		    fprintf(stderr, "Unable to create file for paper, "
+			    "you're on your own.\n");
 		else
 		{
 		    fprintf(fp,
@@ -612,7 +610,6 @@ sort_sigusr1_handler(client,sig,mode)
 /* update focus on graphs */      
       update_all(cg);
       make_format(cg);
-      draw_focus(cg); 
 
 
      unset_wait_cursor(1);
