@@ -15,6 +15,7 @@
 #include "graphutils.h"
 #include "graphutils2.h"
 #include "main.h"
+#include "objutils.h"
 
 #define FRAME_KEY        101
 void generic_done_proc();	/* presently in compwin.c */
@@ -143,17 +144,17 @@ static void graph_focus_notify_proc(item)
 	focus_policy = FOLLOWS;
 	break;
     }
+    draw_focus(cg);
     draw_focus_flag = (int) xv_get(graph_drawfocus_choice_item, PANEL_VALUE) ? ON : OFF;
     newcg = (int) xv_get(graph_setcur_choice_item, PANEL_VALUE);
     if (newcg != cg) {
-	draw_focus(cg);
 	cg = newcg;
 	defineworld(g[cg].w.xg1, g[cg].w.yg1, g[cg].w.xg2, g[cg].w.yg2, islogx(cg), islogy(cg));
 	viewport(g[cg].v.xv1, g[cg].v.yv1, g[cg].v.xv2, g[cg].v.yv2);
 	update_all(cg);
 	make_format(cg);
-	draw_focus(cg);
     }
+    draw_focus(cg);
 }
 
 #if 0
@@ -254,6 +255,7 @@ void create_gactive_frame()
 {
     static Frame top;
     static Panel dialog;
+    Xv_opaque abut, kbut;
 
     if (top) {
 	xv_set(top, WIN_SHOW, TRUE, FRAME_CLOSED, FALSE, 0);
@@ -266,25 +268,33 @@ void create_gactive_frame()
 			       XV_HELP_DATA, "xvgr:gactivate_panel",
 			       PANEL_LAYOUT, PANEL_VERTICAL,
 			       NULL);
-    graph_activate_choice_item = (Panel_item) xv_create(dialog, PANEL_CHOICE_STACK,
-				       XV_HELP_DATA, "xvgr:gactivate_graph",
-						PANEL_LABEL_STRING, "Graph",
-							PANEL_CHOICE_STRINGS,
-			   "0", "1", "2", "3", "4", "5", "6", "7", "8",
-							NULL,
-						    XV_X, xv_col(dialog, 0),
-						    XV_Y, xv_row(dialog, 0),
-							NULL);
-    xv_create(dialog, PANEL_BUTTON,
-	      XV_HELP_DATA, "xvgr:gactivate_apply",
-	      PANEL_LABEL_STRING, "Activate",
-	      PANEL_LABEL_WIDTH, 50,
-	      PANEL_NOTIFY_PROC, graph_activate_notify_proc,
-	      XV_X, xv_col(dialog, 15),
-	      XV_Y, xv_row(dialog, 0),
-	      XV_KEY_DATA, FRAME_KEY, top,
-	      NULL);
-    (void) xv_create(dialog, PANEL_BUTTON,
+    graph_activate_choice_item = (Panel_item)
+	xv_create(dialog, PANEL_CHOICE_STACK,
+		  XV_HELP_DATA, "xvgr:gactivate_graph",
+		  PANEL_LABEL_STRING, "Graph",
+		  PANEL_CHOICE_STRINGS,
+		  "0", "1", "2", "3", "4", "5", "6", "7", "8", NULL,
+		  XV_X, xv_col(dialog, 0),
+		  XV_Y, xv_row(dialog, 0),
+		  NULL);
+    abut = xv_create(dialog, PANEL_BUTTON,
+		     XV_HELP_DATA, "xvgr:gactivate_apply",
+		     PANEL_LABEL_STRING, "Activate",
+		     PANEL_NOTIFY_PROC, graph_activate_notify_proc,
+		     XV_X, xv_col(dialog, 15),
+		     XV_Y, xv_row(dialog, 0),
+		     XV_KEY_DATA, FRAME_KEY, top,
+		     NULL);
+    kbut = xv_create(dialog, PANEL_BUTTON,
+		     XV_HELP_DATA, "xvgr:gactivate_apply",
+		     PANEL_LABEL_STRING, "Kill",
+		     PANEL_NOTIFY_PROC, graph_kill_notify_proc,
+		     XV_X, xv_col(dialog, 15),
+		     XV_Y, xv_row(dialog, 1),
+		     XV_KEY_DATA, FRAME_KEY, top,
+		     NULL);
+    hlw_align(abut, kbut, NULL);
+    abut = xv_create(dialog, PANEL_BUTTON,
 		     XV_HELP_DATA, "xvgr:gactivate_done",
 		     PANEL_LABEL_STRING, "Done",
 		     PANEL_NOTIFY_PROC, generic_done_proc,
@@ -292,15 +302,8 @@ void create_gactive_frame()
 		     XV_Y, xv_row(dialog, 1),
 		     XV_KEY_DATA, FRAME_KEY, top,
 		     NULL);
-    xv_create(dialog, PANEL_BUTTON,
-	      XV_HELP_DATA, "xvgr:gactivate_apply",
-	      PANEL_LABEL_STRING, "Kill",
-	      PANEL_LABEL_WIDTH, 50,
-	      PANEL_NOTIFY_PROC, graph_kill_notify_proc,
-	      XV_X, xv_col(dialog, 15),
-	      XV_Y, xv_row(dialog, 1),
-	      XV_KEY_DATA, FRAME_KEY, top,
-	      NULL);
+    xv_set(abut, XV_X, (xv_col(dialog, 15) -
+			(int) xv_get(abut, XV_WIDTH))/2, NULL); 
     window_fit(dialog);
     window_fit(top);
     xv_set(top, WIN_SHOW, TRUE, 0);
