@@ -688,8 +688,7 @@ int psinitgraphics(dmode)
     devyticl = 20;
     devarrowlength = 20;
 
-/*    fprintf(psout, "%%!PS-Adobe-2.0 EPSF-1.2\n");*/
-    fprintf(psout, "%%!PostScript\n");
+    fprintf(psout, "%%!PS-Adobe-2.0\n");
     fprintf(psout, "%%%%BoundingBox: (atend)\n");
     fprintf(psout, "%%%%Creator: %s\n", version);
     fprintf(psout, "%%%%EndComments\n");
