@@ -17,6 +17,7 @@
 #include "compwin1.h"
 #include "io.h"
 #include "main.h"
+#include "objutils.h"
 #include "setutils.h"
 
 char format[128] = "%lg %lg";	/* for write sets */
@@ -47,6 +48,8 @@ void create_activate_frame()
 {
     static Frame top;
     static Panel dialog;
+    int x;
+    Xv_opaque abut, dbut, rbut, sbut, cbut;
 
     if (top) {
 	xv_set(top, WIN_SHOW, TRUE, FRAME_CLOSED, FALSE, 0);
@@ -59,13 +62,12 @@ void create_activate_frame()
 			       PANEL_LAYOUT, PANEL_VERTICAL,
 			       NULL);
     define_select_set_panel0(dialog, activate_set_item, "Select set :", 20, 0);
-    xv_set(activate_set_item, PANEL_VALUE_X, xv_col(dialog, 16), NULL);
     alength_to_set_item = xv_create(dialog, PANEL_TEXT,
-				    PANEL_VALUE_X, xv_col(dialog, 16),
+				    XV_X, 10,
 				    PANEL_LABEL_STRING, "Length to set:",
 				    PANEL_VALUE_DISPLAY_LENGTH, 10, NULL);
     set_settype_item = (Panel_item) xv_create(dialog, PANEL_CHOICE_STACK,
-					    PANEL_LABEL_STRING, "Set type:",
+					      PANEL_LABEL_STRING, "Set type:",
 					      PANEL_CHOICE_STRINGS,
 					      "XY",
 					      "XY DX",
@@ -76,56 +78,52 @@ void create_activate_frame()
 					      "XY Z",
 					      "XY HILO",
 					      NULL,
-					  PANEL_VALUE_X, xv_col(dialog, 12),
+					      XV_X, 10,
 					      NULL);
-    xv_create(dialog, PANEL_BUTTON,
-	      PANEL_LABEL_STRING, "Activate",
-	      PANEL_LABEL_WIDTH, 80,
-	      PANEL_NOTIFY_PROC, do_activate_proc,
-	      XV_X, xv_col(dialog, 30),
-	      XV_Y, xv_row(dialog, 0),
-	      0);
-    xv_create(dialog, PANEL_BUTTON,
-	      PANEL_LABEL_STRING, "De-activate",
-	      PANEL_LABEL_WIDTH, 80,
-	      PANEL_NOTIFY_PROC, do_deactivate_proc,
-	      XV_HELP_DATA, "xvgr:deactivate_apply",
-	      XV_X, xv_col(dialog, 30),
-	      XV_Y, xv_row(dialog, 1),
-	      0);
-     xv_create(dialog, PANEL_BUTTON,
-	      PANEL_LABEL_STRING, "Re-activate",
-	       PANEL_LABEL_WIDTH, 80,
-	      PANEL_NOTIFY_PROC, do_reactivate_proc,
-	      XV_HELP_DATA, "xvgr:reactivate_apply",
-	      XV_X, xv_col(dialog, 30),
-	      XV_Y, xv_row(dialog, 2),
-	      0);
-     xv_create(dialog, PANEL_BUTTON,
-	      PANEL_LABEL_STRING, "Set length",
-	       PANEL_LABEL_WIDTH, 80,
-	      PANEL_NOTIFY_PROC, do_setlength_proc,
-	      XV_X, xv_col(dialog, 30),
-	      XV_Y, xv_row(dialog, 3),
-	      0);
-    xv_create(dialog, PANEL_BUTTON,
-	      PANEL_LABEL_STRING, "Change type",
-	      PANEL_LABEL_WIDTH, 80,
-	      PANEL_NOTIFY_PROC, do_changetype_proc,
-	      XV_X, xv_col(dialog, 30),
-	      XV_Y, xv_row(dialog, 4),
-	      0);
- 
-
-
-    
-    (void) xv_create(dialog, PANEL_BUTTON,
+    hv_align(activate_set_item, alength_to_set_item, set_settype_item, NULL);
+    x = group_right(activate_set_item, alength_to_set_item, set_settype_item,
+		    NULL) + 10;
+    abut = xv_create(dialog, PANEL_BUTTON,
+		     PANEL_LABEL_STRING, "Activate",
+		     PANEL_NOTIFY_PROC, do_activate_proc,
+		     XV_X, x,
+		     XV_Y, xv_row(dialog, 0),
+		     0);
+    dbut = xv_create(dialog, PANEL_BUTTON,
+		     PANEL_LABEL_STRING, "De-activate",
+		     PANEL_NOTIFY_PROC, do_deactivate_proc,
+		     XV_HELP_DATA, "xvgr:deactivate_apply",
+		     XV_X, x,
+		     XV_Y, xv_row(dialog, 1),
+		     0);
+    rbut = xv_create(dialog, PANEL_BUTTON,
+		     PANEL_LABEL_STRING, "Re-activate",
+		     PANEL_NOTIFY_PROC, do_reactivate_proc,
+		     XV_HELP_DATA, "xvgr:reactivate_apply",
+		     XV_X, x, 
+		     XV_Y, xv_row(dialog, 2),
+		     0);
+    sbut = xv_create(dialog, PANEL_BUTTON,
+		     PANEL_LABEL_STRING, "Set length",
+		     PANEL_NOTIFY_PROC, do_setlength_proc,
+		     XV_X, x, 
+		     XV_Y, xv_row(dialog, 3),
+		     0);
+    cbut = xv_create(dialog, PANEL_BUTTON,
+		     PANEL_LABEL_STRING, "Change type",
+		     PANEL_NOTIFY_PROC, do_changetype_proc,
+		     XV_X, x,
+		     XV_Y, xv_row(dialog, 4),
+		     0);
+    hlw_align(abut, dbut, rbut, sbut, cbut, NULL);
+    dbut = xv_create(dialog, PANEL_BUTTON,
 		     PANEL_LABEL_STRING, "Done",
 		     PANEL_NOTIFY_PROC, generic_done_proc,
-		     XV_X, xv_col(dialog, 10),
+		     XV_X, 10,
 		     XV_Y, xv_row(dialog, 4),
 		     XV_KEY_DATA, FRAME_KEY, top,
 		     NULL);
+    xv_set(dbut, XV_X, (x - (int) xv_get(dbut, XV_WIDTH))/2, NULL);
     window_fit(dialog);
     window_fit(top);
     xv_set(top, WIN_SHOW, TRUE, 0);
@@ -199,7 +197,7 @@ static Panel_item swap_tgraph_item;
 
 static void do_swap_proc();
 static void do_copy_proc();
-static void do_move_proc();
+static void do_set_move_proc();
 
 void create_swap_frame()
 {
@@ -245,7 +243,7 @@ void create_swap_frame()
 	      NULL);
     xv_create(dialog, PANEL_BUTTON,
 	      PANEL_LABEL_STRING, "Move",
-	      PANEL_NOTIFY_PROC, do_move_proc,
+	      PANEL_NOTIFY_PROC, do_set_move_proc,
 	      XV_X, xv_col(dialog, 25),
 	      XV_Y, xv_row(dialog, 2),
 	      NULL);
@@ -286,7 +284,7 @@ static void do_copy_proc()
  * move a set to another set, if the to set doesn't exist
  * get a new one, if it does, ask if it is okay to overwrite
  */
-static void do_move_proc()
+static void do_set_move_proc()
 {
     int j1, j2, gto, gfrom;
 
