@@ -17,9 +17,12 @@
 #include <xview/canvas.h>
 #include <xview/panel.h>
 #include <xview/font.h>
-#include <xview/cursor.h>
 
 #include "globals.h"
+#include "alerts.h"
+#include "checkon.h"
+#include "events.h"
+#include "main.h"
 
 void updatesymbols();
 void updatelegendstr();
@@ -31,15 +34,13 @@ static void update_ledit_items();
 static void load_ledit();
 
 #ifdef __STDC__
-int set_prop(int, ...);
+void set_prop(int, ...);
 #else
-int set_prop();
+void set_prop();
 #endif
 
 int cset = 0;
 
-extern Frame main_frame;
-
 Frame define_symbols_frame;
 static Panel define_symbols_panel;
 
@@ -56,7 +57,6 @@ Panel_item errbar_riserlines_item;
 Panel_item errbar_apply_item;
 
 
-static Panel_item toggle_set_item;
 static Panel_item symbols_apply_item;
 static Panel_item toggle_symbols_item;
 static Panel_item symchar_item;
@@ -71,7 +71,6 @@ static Panel_item toggle_fillusing_item;
 static Panel_item toggle_fillpat_item;
 static Panel_item toggle_fillcol_item;
 static Panel_item toggle_symset_item;
-static Panel_item symmsg;
 
 Frame define_legend_frame;
 static Panel define_legend_panel;
@@ -87,8 +86,6 @@ static Panel_item legends_len_item;
 static Panel_item legend_font_item;
 static Panel_item legend_charsize_item;
 static Panel_item legend_color_item;
-static Panel_item legend_linew_item;
-static Panel_item leglocbut;
 static Panel_item legend_box_item;
 static Panel_item legend_boxfill_item;
 static Panel_item legend_boxfillusing_item;
@@ -108,7 +105,8 @@ Panel ledit_panel;
 static void define_symbols(set_mode)
     int set_mode;
 {
-    int setno, sym, symchar, symskip, symfill, line, pen, wid, fill, fillpat, fillusing, fillcol, i;
+    int setno, sym, symchar, symskip, symfill, line, pen, wid, fill, fillpat;
+    int fillusing, fillcol;
     double symsize;
     char s[30];
     int value = (int) xv_get(symsize_item, PANEL_VALUE);
@@ -261,8 +259,6 @@ void set_cset_proc(w, cd)
  * legends
  */
 
-static int firstrun = TRUE;
-
 /*
  * freshen up legend items, generally after a parameter
  * file has been read
@@ -276,12 +272,6 @@ void updatelegendstr(gno)
     }
 }
 
-/*
- * Cancel proc
- */
-static void reset_symleg_proc()
-{
-}
 
 /*
  * close the symbols/legends popup
@@ -797,9 +787,9 @@ void updatelegends(gno)
 	iv = 100.0 * g[gno].l.charsize;
 	xv_set(legend_charsize_item, PANEL_VALUE, iv, NULL);
 	xv_set(toggle_legends_item, PANEL_VALUE, g[gno].l.active == ON, NULL);
-	sprintf(buf, "%.9lg", g[gno].l.legx);
+	sprintf(buf, "%.9g", g[gno].l.legx);
 	xv_set(legend_x_panel, PANEL_VALUE, buf, NULL);
-	sprintf(buf, "%.9lg", g[gno].l.legy);
+	sprintf(buf, "%.9g", g[gno].l.legy);
 	xv_set(legend_y_panel, PANEL_VALUE, buf, NULL);
 	xv_set(legend_font_item, PANEL_VALUE, g[gno].l.font, NULL);
 	xv_set(legend_color_item, PANEL_VALUE, g[gno].l.color, NULL);
@@ -856,9 +846,6 @@ void define_legends_proc()
  */
 void legend_loc_proc()
 {
-    extern Xv_Cursor cursor_legloc;
-    extern Canvas canvas;
-
     if (define_legend_frame) {
 	g[cg].l.loctype = (int) xv_get(toggle_legendloc_item, PANEL_VALUE) ? VIEW : WORLD;
 /*
@@ -1131,14 +1118,14 @@ static int tcurpage = 0;
 
 static Panel_item ledit_item[MAXPLOT];
 
-static ledit_Done_notify_proc()
+static void ledit_Done_notify_proc()
 {
     xv_set(ledit_frame, WIN_SHOW, FALSE, 0);
 }
 
 static void accept_ledit_proc()
 {
-    int iv, i, j;
+    int i;
 
     for (i = 0; i < MAXPLOT; i++) {
 	strcpy(g[cg].l.str[i].s, (char *) xv_get(ledit_item[i], PANEL_VALUE));
@@ -1147,11 +1134,9 @@ static void accept_ledit_proc()
     drawgraph2(-1);
 }
 
-static void update_ledit_items(gno)
-    int gno;
+static void update_ledit_items()
 {
-    tickmarks t;
-    int i, j, itmp;
+    int i, itmp;
 
     if (ledit_frame) {
 	if (tcurpage == 0) {
@@ -1185,7 +1170,7 @@ static void load_ledit(gno, which)
 static void page_ledit_notify_proc()
 {
     tcurpage = (tcurpage + 1) % NPAGES;
-    update_ledit_items(cg);
+    update_ledit_items();
 }
 
 void create_ledit_frame()
@@ -1194,7 +1179,7 @@ void create_ledit_frame()
     char buf[128];
 
     if (ledit_frame) {
-	update_ledit_items(cg);
+	update_ledit_items();
 	xv_set(ledit_frame, WIN_SHOW, TRUE, FRAME_CLOSED, FALSE, NULL);
 	return;
     }
@@ -1249,33 +1234,28 @@ void create_ledit_frame()
 		     XV_Y, xv_row(ledit_panel, 14),
 		     NULL);
     load_ledit(cg, -1);
-    update_ledit_items(cg);
+    update_ledit_items();
     window_fit(ledit_panel);
     window_fit(ledit_frame);
     xv_set(ledit_frame, WIN_SHOW, TRUE, 0);
 }
 
-extern int check_err;		/* defined in checkon.c TODO blongs in
-				 * globals.h */
-
-
 #ifdef __STDC__
-int
+void
 set_prop(int gno, ...)
 {
 #else
-int
+void
 set_prop(va_alist)
 va_dcl
 {
     int gno;
 #endif
     va_list var;
-    int setno, prop, allsets;
-    int i, j, itmp, startg, endg, starts, ends;
+    int prop, allsets;
+    int i, j, startg, endg, starts, ends;
     double dprop;
-    double dprop1, dprop2;
-    char *cprop;
+/*    double dprop1, dprop2; */
     char buf[256];
 
 #ifdef __STDC__
