@@ -10,14 +10,16 @@
 #include <xview/panel.h>
 
 #include "globals.h"
+#include "alerts.h"
+#include "events.h"
+#include "graphutils2.h"
+#include "main.h"
 
 int snapflag = 0;
 double snapval = 0.0;
 
 void update_world();
 
-extern Frame main_frame;
-
 Frame world_frame = (Frame) NULL;
 Panel world_panel;
 
@@ -168,6 +170,7 @@ static int world_Done_notify_proc(item, event)
     Event *event;
 {
     xv_set(world_frame, WIN_SHOW, FALSE, 0);
+    return XV_OK;
 }
 
 /*ARGSUSED*/
@@ -214,7 +217,7 @@ static int world_accept_notify_proc(item, event)
     Event *event;
 {
     char val[80];
-    int i, which, ming, maxg, errpos;
+    int i, which, ming, maxg;
 
     if (which = (int) xv_get(world_applyto_item, PANEL_VALUE)) {
 	ming = 0;
@@ -284,7 +287,7 @@ Panel_item arrange_applyto_item;
 
 static void define_arrange_proc()
 {
-    int i, j, k, gno, nrows, ncols, pack, applyto = 0;
+    int nrows, ncols, pack;
     double vgap, hgap, sx, sy, wx, wy;
 
     nrows = (int) xv_get(arrange_rows_item, PANEL_VALUE) + 1;
@@ -455,12 +458,9 @@ Panel_item autos_nticksy_item;
 Panel_item autos_applyto_item;
 Panel_item autos_onread_item;
 
-static void world_autotype_notify_proc();
-static int world_aautoset_notify_proc();
-
 static void define_autos_proc()
 {
-    int i, aon, ameth, antx, anty, au, ap, ming, maxg;
+    int aon, ameth, antx, anty, au, ap;
 
     aon = (int) xv_get(autos_on_item, PANEL_VALUE) - 4;
     au = (int) xv_get(autos_using_item, PANEL_VALUE) - 1;
