@@ -164,7 +164,8 @@ static void xlibinit()
     devheightmm = (int) (wy2 / wy1 * win_h);
     if (inc) {
 	gc = DefaultGC(disp, DefaultScreen(disp));
-	gc_val.foreground = WhitePixel(disp, DefaultScreen(disp));
+	gc_val.foreground = WhitePixel(disp, DefaultScreen(disp)) ^
+	    BlackPixel(disp, DefaultScreen(disp));
 	if (invert) {
 	    gc_val.function = GXinvert;
 	} else {
