@@ -1,16 +1,11 @@
-#include <stdio.h>
-#include <math.h>
-
-double legendre(l, x)
-register int l;
-register double x;
+double legendre(register int l, register double x)
 {
     /* x = cos theta on entry */
 
     switch(l)
     {
     case 0:
-	return 1;
+	return 1.0;
     case 1:
 	return x;
     case 2:
@@ -47,9 +42,10 @@ register double x;
 
 #ifdef TEST_LEGENDRE
 
-main(argc, argv)
-int argc;
-char **argv;
+#include <stdio.h>
+#include <math.h>
+
+int main(int argc, char *argv[])
 {
     double min, max, step, x;
     int l;
