@@ -17,13 +17,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-pid_t lookup_proc(
-#if NeedFunctionPrototype
-		  char *proc_name)
-#else
-      proc_name)
-      char *proc_name;
-#endif               /* if NeedFunctionPrototype */
+pid_t lookup_proc(char *proc_name)
 {
       pid_t          psid;
       DIR	     *dirp;
@@ -64,6 +58,7 @@ pid_t lookup_proc(
 			len = (len > PRFNSZ) ? PRFNSZ : len;
 			if (strncmp(proc_name, proc_info.pr_fname, len) == 0) {
 			      (void) close(fd);
+			      closedir(dirp);
 			      return(proc_info.pr_pid);
 			}
 		  }
@@ -80,13 +75,7 @@ pid_t lookup_proc(
 
 #else               /* ifdef SVR4 */
       
-int   lookup_proc(
-#if NeedFunctionPrototype
-      char *proc_name)
-#else
-      proc_name)
-      char *proc_name;
-#endif              /* if NeedFunctionPrototype */
+int   lookup_proc(char *proc_name)
 {
       return(-1);
 }
