@@ -1,3 +1,7 @@
+#define DETPROC_LANG_MASK 1
+#define DETPROC_C 0
+#define DETPROC_F 1
+
 struct namelist {
     char *name;
     struct namelist *next;
@@ -15,21 +19,36 @@ struct detectors {
 	struct detectors *head; /* first detector on next level */
 	struct detectors *next; /* next detector on same level */
     } hitlist;
-    float gain;
-    float offset;
+    double gain;
+    double offset;
     int threshmin;
     int threshmax;
-    float value;
+    double value;
     void *user;		/* Hook to attach user data */
 };
 
+union initfunc {
+    int (*c)(struct detectors *);
+    int (*f)(void);
+};
+
+union eventfunc {
+    int (*c)(int, struct detectors *);
+    int (*f)(int *);
+};
+
 struct information {
     char *name;
+    int ndetel;    /*number of good detector elements, ignoring junk*/
     struct namelist *childnames;
-    int (*preinit)(struct detectors *);
-    int (*init)(struct detectors *);
-    int (*preevent)(int, struct detectors *);
-    int (*event)(int, struct detectors *);
+    union initfunc preinit;
+    union initfunc init;
+    union eventfunc preevent;
+    union eventfunc event;
+    char preinit_type;
+    char init_type;
+    char preevent_type;
+    char event_type;
     struct information *next;
 };
 
@@ -39,3 +58,5 @@ void dumpdetectors(struct detectors *, int);
 int setdetprocs(char *, int (*)(struct detectors *),
 		int (*)(struct detectors *), int (*)(int, struct detectors *),
 		int (*)(int, struct detectors *));
+int setdetprocsmixed(char *, void *, int, void *, int, void *, int, void *,
+		     int);
