@@ -22,12 +22,6 @@
 #include "gui_filepop.h"
 #include "gui_extern.h"
 
-Xv_opaque sort_gui_file_popup_file_popup_create P((Xv_opaque));
-Xv_opaque sort_gui_file_popup_controls_files_create P((Xv_opaque));
-Xv_opaque sort_gui_file_popup_file_list_create P((Xv_opaque));
-Xv_opaque sort_gui_file_popup_file_message_create P((Xv_opaque));
-Xv_opaque sort_gui_file_popup_file_but_create P((Xv_opaque));
-
 int file_load_func P((int));
 int file_save_func P((void));
 
@@ -35,163 +29,83 @@ int file_save_func P((void));
  * Initialize an instance of object `load/save file_popup'.
  */
 sort_gui_file_popup_objects *
-sort_gui_file_popup_objects_initialize(
+sort_gui_file_popup_objects_initialize
 #if NeedFunctionPrototype
-				       sort_gui_file_popup_objects	*ip,
-				       Xv_opaque	owner)
+(sort_gui_file_popup_objects *ip, Xv_opaque owner)
 #else
-      ip, owner)
-      sort_gui_file_popup_objects	*ip;
-      Xv_opaque	owner;
+(ip, owner)
+sort_gui_file_popup_objects *ip;
+Xv_opaque owner;
 #endif
 {
-	if (!ip && !(ip = (sort_gui_file_popup_objects *) calloc(1, sizeof (sort_gui_file_popup_objects))))
-		return (sort_gui_file_popup_objects *) NULL;
-	if (!ip->file_popup)
-		ip->file_popup = sort_gui_file_popup_file_popup_create(owner);
-	if (!ip->controls_files)
-		ip->controls_files = sort_gui_file_popup_controls_files_create(ip->file_popup);
-	if (!ip->file_list)
-		ip->file_list = sort_gui_file_popup_file_list_create(ip->controls_files);
-	if (!ip->file_message)
-		ip->file_message = sort_gui_file_popup_file_message_create(ip->controls_files);
-	if (!ip->file_but)
-		ip->file_but = sort_gui_file_popup_file_but_create(ip->controls_files);
+    extern void file_but_nh P((Panel_item, Event *));
+    extern void keyboardEvent P((Panel_item item, Event *event));
+
+    if (ip)
 	return ip;
-}
 
-/*
- * Create object `file_popup' in the specified instance.
+    if (!(ip = (sort_gui_file_popup_objects *)
+	  calloc(1, sizeof (sort_gui_file_popup_objects))))
+	return (sort_gui_file_popup_objects *) NULL;
 
- */
-Xv_opaque
-sort_gui_file_popup_file_popup_create(
-#if NeedFunctionPrototype
-				      Xv_opaque	owner)
-#else
-      owner)
-      Xv_opaque	owner;
-#endif
-{
-	Xv_opaque	obj;
-	
-	obj = xv_create(owner, FRAME_CMD,
-		XV_WIDTH, 240,
-		XV_HEIGHT, 416,
-		XV_SHOW, FALSE,
-		FRAME_SHOW_FOOTER, TRUE,
-		FRAME_SHOW_RESIZE_CORNER, FALSE,
-		FRAME_CMD_PUSHPIN_IN, TRUE,
-		NULL);
-	xv_set(xv_get(obj, FRAME_CMD_PANEL), WIN_SHOW, FALSE, NULL);
-	return obj;
-}
-/*
- * Create object `controls_files' in the specified instance.
+    ip->file_popup = 
+	xv_create(owner, FRAME_CMD,
+		  XV_WIDTH, 200,
+		  XV_HEIGHT, 200,
+		  XV_SHOW, FALSE,
+		  FRAME_SHOW_FOOTER, FALSE,
+		  FRAME_SHOW_RESIZE_CORNER, FALSE,
+		  FRAME_CMD_PUSHPIN_IN, TRUE,
+		  NULL);
+    ip->controls_files = 
+	xv_create(ip->file_popup, PANEL,
+		  XV_X, 0,
+		  XV_Y, 0,
+		  XV_WIDTH, WIN_EXTEND_TO_EDGE,
+		  XV_HEIGHT, WIN_EXTEND_TO_EDGE,
+		  WIN_BORDER, FALSE,
+		  PANEL_EVENT_PROC, keyboardEvent,
+		  PANEL_ACCEPT_KEYSTROKE, TRUE,
+		  NULL);
+    ip->file_list = 
+	xv_create(ip->controls_files, PANEL_LIST,
+		  XV_X, 10,
+		  XV_Y, 10,
+		  PANEL_LIST_WIDTH, 200,
+		  PANEL_LAYOUT, PANEL_HORIZONTAL,
+		  PANEL_LIST_DISPLAY_ROWS, 18,
+		  PANEL_READ_ONLY, TRUE,
+		  PANEL_CHOOSE_ONE, FALSE,
+		  PANEL_CHOOSE_NONE, TRUE,
+		  NULL);
+    ip->file_message = 
+	xv_create(ip->controls_files, PANEL_MESSAGE,
+		  XV_X, 10,
+		  XV_Y, NEXT_ROW(ip->file_list),
+		  PANEL_LABEL_STRING, "1D 1234 MMMMMMMMMMMMMMM",
+		  PANEL_LABEL_BOLD, FALSE,
+		  NULL);
+    ip->file_but = 
+	xv_create(ip->controls_files, PANEL_BUTTON,
+		  XV_X, 10,
+		  XV_Y, NEXT_ROW(ip->file_message),
+		  PANEL_LABEL_STRING, "Perform",
+		  PANEL_NOTIFY_PROC, file_but_nh,
+		  NULL);
 
- */
-Xv_opaque
-sort_gui_file_popup_controls_files_create(
-#if NeedFunctionPrototype
-					  Xv_opaque	owner)
-#else
-      owner)
-      Xv_opaque	owner;
-#endif
-{
-	Xv_opaque	obj;
-	
-	obj = xv_create(owner, PANEL,
-		XV_X, 0,
-		XV_Y, 0,
-		XV_WIDTH, WIN_EXTEND_TO_EDGE,
-		XV_HEIGHT, WIN_EXTEND_TO_EDGE,
-		WIN_BORDER, FALSE,
-		NULL);
-	return obj;
-}
+    xv_set(ip->file_list, PANEL_LIST_WIDTH,
+	   (int) xv_get(ip->file_message, XV_WIDTH), NULL);
+    xv_set(ip->file_but, XV_X,
+	   ((int) xv_get(ip->file_list, XV_WIDTH) -
+	    (int) xv_get(ip->file_but, XV_WIDTH))/2 + 10, NULL);
+    xv_set(ip->file_message, PANEL_LABEL_STRING,
+	   "No directory specified.", NULL);
 
-/*
- * Create object `file_list' in the specified instance.
+    window_fit(ip->controls_files);
+    window_fit(ip->file_popup);
 
- */
-Xv_opaque
-sort_gui_file_popup_file_list_create(
-#if NeedFunctionPrototype
-				     Xv_opaque	owner)
-#else
-      owner)
-      Xv_opaque	owner;
-#endif
-{
-	Xv_opaque	obj;
-	
-	obj = xv_create(owner, PANEL_LIST,
-		XV_X, 4,
-		XV_Y, 4,
-		PANEL_LIST_WIDTH, 206,
-		XV_HEIGHT, 344,
-		PANEL_LAYOUT, PANEL_HORIZONTAL,
-		PANEL_LIST_DISPLAY_ROWS, 18,
-		PANEL_READ_ONLY, TRUE,
-		PANEL_CHOOSE_ONE, FALSE,
-		PANEL_CHOOSE_NONE, TRUE,
-		NULL);
 
-	return obj;
-}
-
-/*
- * Create object `file_message' in the specified instance.
-
- */
-Xv_opaque
-sort_gui_file_popup_file_message_create(
-#if NeedFunctionPrototype
-					Xv_opaque	owner)
-#else
-      owner)
-      Xv_opaque	owner;
-#endif
-{
-	Xv_opaque	obj;
-	
-	obj = xv_create(owner, PANEL_MESSAGE,
-		XV_X, 4,
-		XV_Y, 365,
-		XV_WIDTH, 220,
-		XV_HEIGHT, 13,
-		PANEL_LABEL_STRING, "No directory specified",
-		PANEL_LABEL_BOLD, FALSE,
-		NULL);
-	return obj;
-}
-
-/*
- * Create object `file_but' in the specified instance.
-
- */
-Xv_opaque
-sort_gui_file_popup_file_but_create(
-#if NeedFunctionPrototype
-				    Xv_opaque	owner)
-#else
-      owner)
-      Xv_opaque	owner;
-#endif
-{
-      extern void file_but_nh P((Panel_item, Event *));
-	Xv_opaque	obj;
-	
-	obj = xv_create(owner, PANEL_BUTTON,
-		XV_X, 85,
-		XV_Y, 390,
-		XV_WIDTH, 70,
-		XV_HEIGHT, 19,
-		PANEL_LABEL_STRING, "Perform",
-		PANEL_NOTIFY_PROC, file_but_nh,
-		NULL);
-	return obj;
+    return ip;
 }
 
 /************************* file popup **************************************************/
@@ -274,7 +188,7 @@ file_but_nh(
       return;
 }
 
-/***********************************************************************************************/
+
 static char *spec_class[] = { "1D", "2D", (char *)0};
 int
 file_save_func(
@@ -346,7 +260,7 @@ file_load_func(
       return(0);
 }
 
-/***********************************************************************************************/
+
 /*
  * Function to update scrolling list for file_popup_list
  */
@@ -377,4 +291,4 @@ write_to_file_popup_list(
 	return;
 }
 
-/***********************************************************************************************/
+
