@@ -24,7 +24,10 @@ typedef struct {
 sort_gui_spec_popup_objects *sort_gui_spec_popup_objects_initialize
     P((sort_gui_spec_popup_objects * , Xv_opaque));
 
-void spec_popup_spec1d_list_update P((int, char *));
-void spec_popup_spec2d_list_update P((int, char *));
-
 extern sort_gui_spec_popup_objects *sort_gui_spec_popup;
+
+int list_reset P((Xv_opaque, Xv_opaque *, int));
+void spec_popup_spec1d_list_reset P((char **));
+
+#define LIST_FIRST 1
+#define LIST_END 1
