@@ -5,6 +5,7 @@
 #include <sys/types.h>
 #include <sys/mman.h>
 #include <time.h>
+#include <sys/time.h>
 #include <fcntl.h>
 #include <thread.h>
 #include <synch.h>
@@ -14,6 +15,10 @@
 #include "eg.h"
 #include "data_io.h"
 #include "main.h"
+#include "version.h"
+#ifdef USE_DATA_QUEUE
+#include "data_queue.h"
+#endif
 
 struct shared_data    *sdat_ptr;
 
@@ -48,7 +53,7 @@ char *progname;
     }
     (void) close(filedes);
 
-    /* calculate size of shared data space to allow read/write access too */
+    /* calculate size of shared data space to allow read/write access to */
     len = (char *)sdat_ptr - (char *) &sdat_ptr->_pad;
     len = (len < 0) ? -len : len;
     
@@ -60,8 +65,8 @@ char *progname;
     
     /* check version compatibilty */
     if (sdat_ptr->version != SUNSORT_VERSION) {
-	fprintf(stderr,"inconsistent version numbers ... remake %s\n",
-		progname);
+	fprintf(stderr,"inconsistent version numbers %d != %d ... remake %s\n",
+		sdat_ptr->version, SUNSORT_VERSION, progname);
 	return -1;
     }
     
@@ -190,9 +195,11 @@ unmap_spectrum(
 }
 
 /* pointers and buffer position counters for block I/O */
+#ifndef USE_DATA_QUEUE
 static int        rbuffer_pos, rdeod;
-static data_buf_t *rdptr; 
 static int        wbuffer_pos;
+#endif
+static data_buf_t *rdptr; 
 static data_buf_t *wdptr;
 
 void
@@ -204,12 +211,16 @@ init_blockio
 #endif
 {
     /* initialize read state I/O */
+#ifndef USE_DATA_QUEUE
     rbuffer_pos = 0;
-    rdptr = NULL;
     rdeod = 0;
+#endif
+    rdptr = NULL;
 
     /* initialize write state I/O */
+#ifndef USE_DATA_QUEUE
     wbuffer_pos = 0;
+#endif
     wdptr = NULL;
 
     return;
@@ -224,6 +235,33 @@ read_block
 int *bytes;
 #endif
 {
+#ifdef USE_DATA_QUEUE
+    int b;
+    spec_buf_flush_safe(1);
+
+    /* If we have a block, put it at end of empty queue */
+    if (rdptr != NULL)
+    {
+	sdat_ptr->in_records++;
+	add_to_queue(&sdat_ptr->read_empty, rdptr - sdat_ptr->read_buf);
+    }
+
+    /* Get the next block */
+    while ((b = take_from_queue(&sdat_ptr->read_full, NULL)) == -1)
+	;
+    rdptr = sdat_ptr->read_buf + b;
+    if (rdptr->data_size == 0)
+    {
+	add_to_queue(&sdat_ptr->read_empty, b);
+	rdptr = NULL;
+	return NULL;
+    }
+
+    spec_buf_flush_safe(0);
+    *bytes = rdptr->data_size;
+    return (short *) rdptr->data;
+#else
+    spec_buf_flush_safe(1);
     /* put last block on empty block queue */
     if (rdptr != NULL) {
 	(void) mutex_lock(&rdptr->mp);
@@ -266,8 +304,10 @@ int *bytes;
     *bytes = rdptr->data_size;
     (void) mutex_unlock(&rdptr->mp);
     
+    spec_buf_flush_safe(0);
     /*LINTED*/
     return((short *) rdptr->data);	
+#endif
 }
 
 /*
@@ -288,13 +328,23 @@ software_eod
     kill(getppid(),SIGUSR1); 
 
     /* Give server a chance to stop if it hasn't already */
+#ifndef USE_DATA_QUEUE
     if (!rdeod)
+#endif
 	sleep(1);
 
     /* Flush any pending blocks */
+#ifdef USE_DATA_QUEUE
+    while(read_block(&bytes) != NULL)
+#else
     while(rdeod == 0 && read_block(&bytes) != NULL)
+#endif
 	fprintf(stderr, "sort: Discarding record from input pipeline.\n");
 
+#ifdef USE_DATA_QUEUE
+    if (DBX_val >= 7)
+	fprintf(stderr,"sort process signaled EOD\n");
+#else
     /* ensure last block is registered as EOD block */
     if (rdptr != NULL) {
 	(void) mutex_lock(&rdptr->mp);
@@ -302,10 +352,11 @@ software_eod
 	(void) cond_signal(&rdptr->cv);
 	(void) mutex_unlock(&rdptr->mp);
     }
-      
     if (DBX_val >= 7)
 	fprintf(stderr,"sort process signaled EOD for buffer %d\n",
 		rbuffer_pos);
+#endif
+      
     
     /* set sorting state to OFF */
     (void) mutex_lock(&sdat_ptr->mp_sorting);
@@ -318,18 +369,49 @@ software_eod
 
 
 short *
-write_block(
+write_block
 #if NeedFunctionPrototype
-		  int bytes, int endflag)
+(int bytes, int endflag)
 #else
-      bytes, endflag)
-      int bytes;
-      int endflag;
+(bytes, endflag)
+int bytes;
+int endflag;
 #endif
 {
       static timestruc_t to;
+#ifdef USE_DATA_QUEUE
+      int b;
+#endif
+
       to.tv_nsec = 0;
-      
+
+#ifdef USE_DATA_QUEUE
+      /* put last block on full block queue */
+      if (wdptr != NULL)
+      {
+	  wdptr->data_size = bytes;
+	  add_to_queue(&sdat_ptr->write_full, wdptr - sdat_ptr->write_buf);
+      }
+
+      /* get new block of data */
+      while((b = take_from_queue(&sdat_ptr->write_empty, NULL)) == -1)
+	  ;
+      wdptr = sdat_ptr->write_buf + b;
+      /* see whether output device has had any problems */
+      if (wdptr->data_size == 0)
+      {
+	  add_to_queue(&sdat_ptr->write_empty, b);
+	  wdptr = NULL;
+	  return NULL;
+      }
+      if (endflag)
+      {
+	  wdptr->data_size = 0;
+	  add_to_queue(&sdat_ptr->write_full, b);
+	  wdptr = NULL;
+      }
+      return (short *) wdptr->data;
+#else      
 /* put last block on full block queue */
       if (wdptr != NULL) {
 	    (void) mutex_lock(&wdptr->mp);
@@ -367,7 +449,7 @@ write_block(
       else
 	    wdptr->state = FILLING_BUF;
       (void) mutex_unlock(&wdptr->mp);
-
       /*LINTED*/
       return((short *) wdptr->data);	
+#endif
 }
