@@ -39,6 +39,7 @@ struct vars_common {
 };
 
 struct adclist_common {
+    short grouplist[NOS_EG_GROUPS+1];
     short adclist[NOS_ADC_WORDS+1];
 };
 
@@ -64,8 +65,12 @@ int rdtape_user_init P((void));
 int rdtape_user_sortin P((void));
 int rdtape_user_finish P((void));
 
-/* Common messages */
-extern const char initfailmess[], sortinfailmess[], finishfailmess[];
+/* Wrapper functions */
+int call_init P((void));
+int call_finish P((void));
+
+/* Common message */
+extern const char sortinfailmess[];
 
 /* function prototypes for block handling routines*/
 short *read_block P((int *));
