@@ -26,8 +26,6 @@
 #define ANU_RECORD_HWM       8100
 #define ANU_BUFHEADER_WORDS  16
 
-#define SWAPSHORT(x) (x)
-
 /*
 #define MANY_MODULES
 */
@@ -65,11 +63,8 @@ int filter;
     bit_bytes = sizeof(adcs_.bitpattern);
       
 /* call user's initialization function */      
-    if (init())
-    {
-	fprintf(stderr, initfailmess);
+    if (call_init())
 	return filter;
-    }
       
     /* set start time */
     start_time = time(NULL);
@@ -93,8 +88,7 @@ int filter;
 	/* Switch whole buffer from little endian shorts to big endian */
 	/*LINTED*/
 	for(i = bytes>>2, p = (unsigned int *) ebye; i--; p++)
-	    *p = ((*p & 0xff000000)>>8) | ((*p & 0x00ff0000) << 8) |
-		((*p & 0x0000ff00) >> 8) | ((*p & 0x000000ff) <<8);
+	    *p = ((*p & 0xff00ff00)>>8) | ((*p & 0x00ff00ff) << 8);
 
 	/* get number of events in this block */
 	nos_events = ebye[13];
@@ -114,6 +108,7 @@ int filter;
 	    (void) memset((char *) adcs_.adcs, -1, adc_bytes);
 	    (void) memset((char *) adcs_.bitpattern, 0, bit_bytes);
 	    adclist = adclist_.adclist;
+	    *adclist_.grouplist = -1;
 
 	    /* decode event header */
 	    header_ptr = eptr;
@@ -204,8 +199,7 @@ ABORT_SORT:
     time_now = time(NULL);
 
 /* call user provided clearup routine  */
-    if (finish())
-	fprintf(stderr, finishfailmess);
+    call_finish();
 
 /* output statistics */
     fprintf(stderr,"\n*** sort statistics ***\n");
@@ -235,7 +229,7 @@ filt_tail(
       short *fptr;
 #endif
 {
-      base[13] = SWAPSHORT(fevents);
+      base[13] = fevents;
       return;
 }
 /*
