@@ -7,30 +7,10 @@
 #include "rdtape.h"
 #include "rdtape_eg.h"
 
-int
-rdtape_demon(
-#if NeedFunctionPrototype
-	  int filter)
-#else
-      filter)
-      int filter;
-#endif
-{
-    return rdtape_eg(filter, STYLE_EGAM);
-}
-
-int
-write_demon(
-#if NeedFunctionPrototype
-	  int size, short *array)
-#else
-      size, array)
-      int size;
-      short *array;
-#endif
-{
-    return(write_eg(size, array, STYLE_EGAM));
-}
+#define STYLE_EGAM
+#define DECODER_NAME rdtape_demon
+#define ENCODER_NAME write_demon
+#include "rdtape_eg_core.c"
 
 /* demon filter data specification */
 static filtdat_t demon_filtdat = {
