@@ -1,8 +1,11 @@
+#define DELIMITER_MASK     0xffff
 #define EG_RECORD_HWM      16000
 #define EG_RECORD_COUNT    16384
+#define EG_ADDR_SIZE       0x4000
 
-#define STYLE_EGAM	0	/* True Eurogam */
-#define STYLE_MEGHA	1	/* Our fudged version */
+extern struct group_data groups[NOS_EG_GROUPS];
+extern short *addr2adc[EG_ADDR_SIZE];
+extern short adc2addr[NOS_ADC_WORDS];
 
 #if NeedFunctionPrototype
 int rdtape_eg(int, int);
