@@ -49,11 +49,8 @@ int filter;
     bit_bytes = sizeof(adcs_.bitpattern);
     
 /* call user's initialization function */      
-    if (init())
-    {
-	fprintf(stderr, initfailmess);
+    if (call_init())
 	return filter;
-    }
     
 /* set start time */
     start_time  = time(NULL);
@@ -70,6 +67,7 @@ int filter;
 	    (void) memset((char *) adcs_.adcs, -1, adc_bytes);
 	    (void) memset((char *) adcs_.bitpattern, 0, bit_bytes);
 	    adclist = adclist_.adclist;
+	    *adclist_.grouplist = -1;
 
 	    /* decode event header */
 	    adcs_.triggernos = trig_nos = (header & 0xff00) >> 8;
@@ -124,8 +122,7 @@ ABORT_SORT:
     time_now = time(NULL);
     
 /* call user provided clearup routine  */
-      if (finish())
-	  fprintf(stderr, finishfailmess);
+    call_finish();
       
 /* output statistics */
       fprintf(stderr,"\n*** sort statistics ***\n");
