@@ -78,13 +78,11 @@ int filter;
     adc_bytes = adcnum_.nos_adcs * sizeof(short);
     
     /* call user's initialization function */      
-    if (init())
-    {
-	fprintf(stderr, initfailmess);
+    if (call_init())
 	return filter;
-    }
 
     adclist = adclist_.adclist;
+    *adclist_.grouplist = -1;
 		
     /* set start time */
     start_time = time(NULL);
@@ -265,6 +263,7 @@ int filter;
 	    {
 		memset((char *) adcs_.adcs, -1, adc_bytes);
 		adclist = adclist_.adclist;
+		*adclist_.grouplist = -1;
 		adcp = 0;
 	    }
 	    if (*ebye & 0x8000)
@@ -342,8 +341,7 @@ ABORT_SORT:
     time_now = time(NULL);
     
     /* call user provided clearup routine  */
-    if (finish())
-	fprintf(stderr, finishfailmess);
+    call_finish();
   
     /* output statistics */
     record--;
