@@ -195,11 +195,8 @@ int filter;
     adc_bytes = adcnum_.nos_adcs * sizeof(short);
 
     /* call user's initialization function */      
-    if (init())
-    {
-	fprintf(stderr, initfailmess);
+    if (call_init())
 	return filter;
-    }
   
     /* set start time */
     start_time = time(NULL);
@@ -309,6 +306,7 @@ int filter;
 			   adc_bytes - len*sizeof(short));
 		}
 		
+		*adclist_.grouplist = -1;
 		i = (len > adcnum_.nos_adcs) ? adcnum_.nos_adcs : len;
 		adclist = adclist_.adclist + i;
 		*adclist = -1;
@@ -396,8 +394,7 @@ ABORT_SORT:
     time_now = time(NULL);
     
     /* call user provided clearup routine  */
-    if (finish())
-	fprintf(stderr, finishfailmess);
+    call_finish();
 
     /* output statistics */
     record--;
