@@ -38,11 +38,8 @@ int filter;
     adc_bytes = adcnum_.nos_adcs * sizeof(short);
 
     /* call user's initialization function */      
-    if (init())
-    {
-	fprintf(stderr, initfailmess);
+    if (call_init())
 	return filter;
-    }
   
     /* set start time */
     start_time = time(NULL);
@@ -64,6 +61,7 @@ int filter;
 	{
 	    memset((char *) adcs_.adcs, -1, adc_bytes);
 	    adclist = adclist_.adclist;
+	    *adclist_.grouplist = -1;
 	    
 	    for(i = NUM_ADCS, ptr = ebye, adcp = adcs_.adcs; i--; )
 	    {
@@ -98,8 +96,7 @@ ABORT_SORT:
     time_now = time(NULL);
     
     /* call user provided clearup routine  */
-    if (finish())
-	fprintf(stderr, finishfailmess);
+    call_finish();
 
     /* output statistics */
     record--;
