@@ -47,11 +47,8 @@ int filter;
     event_len = adcnum_.nos_adcs;
     
     /* call user's initialization function */      
-    if (init())
-    {
-	fprintf(stderr, initfailmess);
+    if (call_init())
 	return filter;
-    }
 
 /* set start time */
     start_time = time(NULL);
@@ -74,6 +71,7 @@ int filter;
 	    (void) memcpy((char *) adcs_.adcs, eptr, adc_bytes);
 	    adcs_.wrtevt = 0;
 	    *adclist_.adclist = -1;
+	    *adclist_.grouplist = -1;
 	    
 	    /* call user's sort routine */
 	    if (sortin())
@@ -100,8 +98,7 @@ ABORT_SORT:
     time_now = time(NULL);
     
 /* call user provided clearup routine  */
-    if (finish())
-	  fprintf(stderr, finishfailmess);
+    call_finish();
  
 /* output statistics */
     fprintf(stderr,"\n*** sort statistics ***\n");
