@@ -88,11 +88,8 @@ int filter;
       adc_bytes = adcnum_.nos_adcs * sizeof(short);
       
 /* call user's initialization function */      
-      if (init())
-      {
-	  fprintf(stderr, initfailmess);
+      if (call_init())
 	  return filter;
-      }
       
 /* set start time */
       start_time = time(NULL);
@@ -186,6 +183,7 @@ int filter;
 	      /* reset adcs_ common block */
 	      (void) memset((char *) adcs_.adcs, -1, adc_bytes);
 	      adclist = adclist_.adclist;
+	      *adclist_.grouplist = -1;
 
 	      /* pack adc array */
 	      if (event_len <= adcnum_.nos_adcs) {
@@ -241,8 +239,7 @@ ABORT_SORT:
       time_now = time(NULL);
       
 /* call user provided clearup routine  */
-      if (finish())
-	  fprintf(stderr, finishfailmess);
+      call_finish();
       
 /* output statistics */
       fprintf(stderr,"\n*** sort statistics ***\n");
