@@ -75,11 +75,8 @@ int filter;
     bit_bytes = sizeof(adcs_.bitpattern);
     
     /* call user's initialization function */      
-    if (init())
-    {
-	fprintf(stderr, initfailmess);
+    if (call_init())
 	return filter;
-    }
     
     /* set start time */
     start_time  = time(NULL);
@@ -124,6 +121,7 @@ int filter;
 	    (void) memset((char *) adcs_.adcs, -1, adc_bytes);
 	    (void) memset((char *) adcs_.bitpattern, 0, bit_bytes);
 	    adclist = adclist_.adclist;
+	    *adclist_.grouplist = -1;
 	    
 	    /* decode event header */
 	    adcs_.triggernos = trig_nos = ((header & TRIGNOS_MASK) >> 8) + 1;
@@ -220,8 +218,7 @@ ABORT_SORT:
     time_now = time(NULL);
     
     /* call user provided clearup routine  */
-    if (finish())
-	fprintf(stderr, finishfailmess);
+    call_finish();
 
     /* output statistics */
     fprintf(stderr,"\n*** sort statistics ***\n");
