@@ -76,11 +76,8 @@ int filter;
     bit_bytes = sizeof(adcs_.bitpattern);
       
     /* call user's initialization function */      
-    if (init())
-    {
-	fprintf(stderr, initfailmess);
+    if (call_init())
 	return filter;
-    }
 
     /* set start time */
     start_time  = time(NULL);
@@ -125,6 +122,7 @@ int filter;
 	    (void) memset((char *) adcs_.adcs, -1, adc_bytes);
 	    (void) memset((char *) adcs_.bitpattern, 0, bit_bytes);
 	    adclist = adclist_.adclist;
+	    *adclist_.grouplist = -1;
 
 	    /* decode event header */
 	    adcs_.triggernos = trig_nos = ((header & TRIGNOS_MASK) >> 8) + 1;
@@ -220,8 +218,7 @@ ABORT_SORT:
     time_now = time(NULL);
       
     /* call user provided clearup routine  */
-    if (finish())
-       fprintf(stderr, finishfailmess);
+    call_finish();
       
     /* output statistics */
     fprintf(stderr,"\n*** sort statistics ***\n");
@@ -344,11 +341,11 @@ short *array;
  */
 /*ARGSUSED*/
 static void
-filt_tail(
+filt_tail
 #if NeedFunctionPrototype
-	  short *base, short *fptr)
+(short *base, short *fptr)
 #else
-    base, fptr)
+(base, fptr)
 short *base;
 short *fptr;
 #endif
@@ -358,10 +355,8 @@ short *fptr;
     fptr[1] = *fptr = 0;
 
     /*LINTED*/
-    for(p = (unsigned int *) base; p < (unsigned int *) fptr; p++)
+    for(p = (unsigned int *) (base + 12); p < (unsigned int *) fptr; p++)
 	*p = ((*p & 0xffff0000)>>16) | ((*p & 0x0000ffff)<<16);
-
-    return;
 }
 
 /*
