@@ -10,7 +10,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <malloc.h>
-
 #include <sys/types.h>
 #include <sys/mman.h>
 
@@ -20,11 +19,16 @@
 #include "data_io.h"
 #include "spectra.h"
 #include "spectraint.h"
+#include "spectra_buf.h"
 
 int make_1d P((int, int, char *, spec_entry_t *));
 int make_2d P((int, int, char *, spec_entry_t *));
 int make_var P((int, float, char *, spec_entry_t *));
 
+spec_1d_t *tab_1d[TAB_SIZE_1D];
+spec_2d_t *tab_2d[TAB_SIZE_2D];
+static var_str_t *tab_var[TAB_SIZE_VAR];
+
 int
 read_spectra_data
 #if NeedFunctionPrototype
@@ -48,7 +52,7 @@ read_spectra_data
 	if (make_1d(i, sp->size, sp->name, sp) == SORT_FAIL)
 	    return(SORT_FAIL);
 	if(DBX_val >= 7)
-	    fprintf(stderr, "sort: 1d spectrum %s nos %d with size %d\n",
+	    fprintf(stderr, "sort: 1d spectrum %s number %d with size %d\n",
 		    sp->name, i, sp->size);
     }
     /* setup the 2d spectra */
@@ -63,7 +67,7 @@ read_spectra_data
 	if (make_2d(i, sp->size, sp->name, sp) == SORT_FAIL)
 	    return(SORT_FAIL);
 	if(DBX_val >= 7)
-	    fprintf(stderr, "sort: 2d spectrum %s nos %d with size %d\n",
+	    fprintf(stderr, "sort: 2d spectrum %s number %d with size %d\n",
 		    sp->name, i, sp->size);
     }
     /* set up the variables */
@@ -77,24 +81,13 @@ read_spectra_data
 	if (make_var(i, sp->value, sp->name, sp) == SORT_FAIL)
 	    return(SORT_FAIL);
 	if(DBX_val >= 7)
-	    fprintf(stderr, "sort: variable %s nos %d with value %g\n",
+	    fprintf(stderr, "sort: variable %s number %d with value %g\n",
 		    sp->name, i, sp->value);
     }
 
     return(0);
 }
 
-/*
- * The elements of tab_?d contain pointers to the storage locations
- * of each spectrum structure. ie nos_tab_1d[1] points to the first
- * address location of the 1d spectrum structure for spectrum number
- * 1. Element [0] will point to the last structure to be filled
- * spectrum
- */
-static spec_1d_t *tab_1d[TAB_SIZE_1D];
-static spec_2d_t *tab_2d[TAB_SIZE_2D];
-static var_str_t *tab_var[TAB_SIZE_VAR];
-
 int
 make_1d
 #if NeedFunctionPrototype
@@ -476,366 +469,6 @@ int var_nos; /* spectrum number as defined by user */
  *           user callable spectrum incrementing subroutines etc.           *
  ****************************************************************************/
 
-#include <limits.h>
-
-void
-inc1d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int channel)
-#else
-(spec_nos, channel)
-register int spec_nos;
-register int channel;
-#endif
-{
-    register spec_1d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_1D) {
-	fprintf(stderr, "inc1d to invalid 1d spectrum number %d", spec_nos);
-	return;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_1d[spec_nos])) {
-	fprintf(stderr, "inc1d to undefined 1d spectrum nos %d\n", spec_nos);
-	return;
-    }
-
-    if (channel < 0 || channel >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr, "inc1d to channel %d outside spectrum range\n",
-		    channel);
-	return;
-    }
-    if ((ptr->data[channel])++ == INT_MAX) {
-	fprintf(stderr, "inc1d overflow at channel %d in spectrum %s\n",
-		channel, ptr->sp->name);
-	return;
-    }
-    return;
-}
-
-void
-inc2d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int x_ch,
-register int y_ch)
-#else
-(spec_nos, x_ch, y_ch)
-register int spec_nos;
-register int x_ch;
-register int y_ch;
-#endif
-{
-    register spec_2d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_2D) {
-	fprintf(stderr, "inc2d to invalid 2d spectrum number %d", spec_nos);
-	return;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_2d[spec_nos])) {
-	fprintf(stderr, "inc2d to undefined 2d spectrum nos %d\n", spec_nos);
-	return;
-    }
-
-    if (x_ch < 0 || x_ch >= ptr->sp->size ||
-	y_ch < 0 || y_ch >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr,
-		    "inc2d to x=%d y=%d outside range of spectrum %s\n",
-		    x_ch, y_ch, ptr->sp->name);
-	return;
-    }
-    if ((ptr->data[(y_ch) + (x_ch)*(ptr->sp->size)])++ == INT_MAX) {
-	fprintf(stderr, "inc2d overflow at x=%d, y=%d in spectrum %s\n",
-		x_ch, y_ch, ptr->sp->name);
-	return;
-    }
-    return;
-}
-
-void
-incv1d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int channel,
-register int value)
-#else
-(spec_nos, channel, value)
-register int spec_nos;
-register int channel;
-register int value;
-#endif
-{
-    register spec_1d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_1D) {
-	fprintf(stderr, "incv1d to invalid 1d spectrum number %d", spec_nos);
-	return;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_1d[spec_nos])) {
-	fprintf(stderr, "incv1d to undefined 1d spectrum nos %d\n", spec_nos);
-	return;
-    }
-
-    if (channel < 0 || channel >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr, "incv1d to channel %d outside spectrum range\n",
-		    channel);
-	return;
-    }
-    if ((ptr->data[channel]) >= (INT_MAX - value)) {
-	fprintf(stderr, "incv1d overflow at channel %d in spectrum %s\n",
-		channel, ptr->sp->name);
-	return;
-    }
-    ptr->data[channel] += value;
-    return;
-}
-
-void
-incv2d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int x_ch,
-register int y_ch,
-register int value)
-#else
-(spec_nos, x_ch, y_ch, value)
-register int spec_nos;
-register int x_ch;
-register int y_ch;
-register int value;
-#endif
-{
-    register spec_2d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_2D) {
-	fprintf(stderr, "incv2d to invalid 2d spectrum number %d", spec_nos);
-	return;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_2d[spec_nos])) {
-	fprintf(stderr, "incv2d to undefined 2d spectrum nos %d\n", spec_nos);
-	return;
-    }
-
-    if (x_ch < 0 || x_ch >= ptr->sp->size ||
-	y_ch < 0 || y_ch >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr,
-		    "incv2d to x=%d y=%d outside range of spectrum %s\n",
-		    x_ch, y_ch, ptr->sp->name);
-	return;
-    }
-    if ((ptr->data[(y_ch)+(x_ch)*(ptr->sp->size)]) >= (INT_MAX - value)) {
-	fprintf(stderr, "incv2d overflow at x=%d, y=%d in spectrum %s\n",
-		x_ch, y_ch, ptr->sp->name);
-	return;
-    }
-
-    ptr->data[(y_ch)+(x_ch)*(ptr->sp->size)] += value;
-    return;
-}
-
-int
-win2d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int x_ch,
-register int y_ch)
-#else
-(spec_nos, x_ch, y_ch)
-register int spec_nos;
-register int x_ch;
-register int y_ch;
-#endif
-{
-    register spec_2d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_2D) {
-	fprintf(stderr, "win2d to invalid 2d spectrum number %d\n", spec_nos);
-	return SORT_FALSE;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_2d[spec_nos])) {
-	fprintf(stderr, "win2d to undefined 2d spectrum nos %d\n", spec_nos);
-	return SORT_FALSE;
-    }
-
-    if (!ptr->win) {
-	fprintf(stderr, "win2d called with non window 2d spectrum nos %d\n",
-		spec_nos);
-	return SORT_FALSE;
-    }
-
-    if (x_ch < 0 || x_ch >= ptr->sp->size ||
-	y_ch < 0 || y_ch >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr,
-		    "win2d to x=%d y=%d outside range of spectrum %s\n",
-		    x_ch, y_ch, ptr->sp->name);
-	return SORT_FALSE;
-    }
-
-    return ((ptr->data[(y_ch)+(x_ch)*(ptr->sp->size)]) > 10) ? SORT_TRUE
-	: SORT_FALSE;
-}
-
-void
-set1d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int channel,
-register int value)
-#else
-(spec_nos, channel, value)
-register int spec_nos;
-register int channel;
-register int value;
-#endif
-{
-    register spec_1d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_1D) {
-	fprintf(stderr, "set1d to invalid 1d spectrum number %d", spec_nos);
-	return;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_1d[spec_nos])) {
-	fprintf(stderr, "set1d to undefined 1d spectrum nos %d\n", spec_nos);
-	return;
-    }
-
-    if (channel < 0 || channel >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr, "set1d to channel %d outside spectrum range\n",
-		    channel);
-	return;
-    }
-    ptr->data[channel] = value;
-    return;
-}
-
-void
-set2d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int x_ch,
-register int y_ch,
-register int value)
-#else
-(spec_nos, x_ch, y_ch, value)
-register int spec_nos;
-register int x_ch;
-register int y_ch;
-register int value;
-#endif
-{
-    register spec_2d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_2D) {
-	fprintf(stderr, "set2d to invalid 2d spectrum number %d", spec_nos);
-	return;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_2d[spec_nos])) {
-	fprintf(stderr, "set2d to undefined 2d spectrum nos %d\n", spec_nos);
-	return;
-    }
-
-    if (x_ch < 0 || x_ch >= ptr->sp->size ||
-	y_ch < 0 || y_ch >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr,
-		    "set2d to x=%d y=%d outside range of spectrum %s\n",
-		    x_ch, y_ch, ptr->sp->name);
-	return;
-    }
-    ptr->data[(y_ch)+(x_ch)*(ptr->sp->size)] = value;
-    return;
-}
-
-int
-val1d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int channel)
-#else
-(spec_nos, channel)
-register int spec_nos;
-register int channel;
-#endif
-{
-    register spec_1d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_1D) {
-	fprintf(stderr, "val1d to invalid 1d spectrum number %d", spec_nos);
-	return -1;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_1d[spec_nos])) {
-	fprintf(stderr, "val1d to undefined 1d spectrum nos %d\n", spec_nos);
-	return -1;
-    }
-
-    if (channel < 0 || channel >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr, "val1d to channel %d outside spectrum range\n",
-		    channel);
-	return -1;
-    }
-    return ptr->data[channel];
-}
-
-int
-val2d
-#if NeedFunctionPrototype
-(register int spec_nos,
-register int x_ch,
-register int y_ch)
-#else
-(spec_nos, x_ch, y_ch)
-register int spec_nos;
-register int x_ch;
-register int y_ch;
-#endif
-{
-    register spec_2d_t *ptr;
-
-    if (spec_nos <= 0 || spec_nos >= TAB_SIZE_2D) {
-	fprintf(stderr, "val2d to invalid 2d spectrum number %d", spec_nos);
-	return -1;
-    }
-
-    /*LINTED*/
-    if (!(ptr = tab_2d[spec_nos])) {
-	fprintf(stderr, "val2d to undefined 2d spectrum nos %d\n", spec_nos);
-	return -1;
-    }
-
-    if (x_ch < 0 || x_ch >= ptr->sp->size ||
-	y_ch < 0 || y_ch >= ptr->sp->size) {
-	if (DBX_val >= 10)
-	    fprintf(stderr,
-		    "val2d to x=%d y=%d outside range of spectrum %s\n",
-		    x_ch, y_ch, ptr->sp->name);
-	return -1;
-    }
-    return ptr->data[(y_ch) + (x_ch)*(ptr->sp->size)];
-}
-
 /* FORTRAN equivalent routines */
 
 void
@@ -1721,7 +1354,7 @@ delete_spectra
 	var = var->next;
 	if (delete_var(nos) == SORT_FAIL) {
 	    fprintf(stderr, "delete_spectra (sort): failed to delete "
-		    "variable nos %d\n", nos);
+		    "variable number %d\n", nos);
 	    ret_code += 0x4;
 	    break;
 	}
@@ -1781,7 +1414,7 @@ remake_spectra
 	    }
 	    if(DBX_val >= 7)
 		fprintf(stderr,
-			"sort: remade 1d spectrum %s nos %d with size %d\n",
+			"sort: remade 1d spectrum %s number %d with size %d\n",
 			sp->name, nos, sp->size);
 	}
     }
@@ -1815,7 +1448,7 @@ remake_spectra
 		break;
 	    }
 	    if(DBX_val >= 7)
-		fprintf(stderr, "sort: remade 2d spectrum %s nos %d with "
+		fprintf(stderr, "sort: remade 2d spectrum %s number %d with "
 			"size %d win = %d\n",
 			sp->name, nos, sp->size, sp->win);
 	}
