@@ -1,7 +1,15 @@
 /*spectra.h      declarations for spectrum manipulation routines*/
 
+struct spec2d_list {
+    int x;
+    int y;
+};
+
 void inc1d P((int, int));
 void inc2d P((int, int, int));
+void inc2d_list P((int, struct spec2d_list *, int));
+void inc2d_col P((int, int, int *));
+void inc2d_tartan P((int, int *));
 void incv1d P((int, int, int));
 void incv2d P((int, int, int, int));
 int win2d P((int, int, int));
