@@ -6,6 +6,7 @@
 #include <sys/types.h>
 #include "sort_def.h"
 #include "sort_threadint.h"
+#include "data_pipe.h"
 #include "r_dev.h"
 #include "monDrv.h"
 #include "dbufLib.h"
@@ -16,8 +17,7 @@ typedef struct mpSem *MP_SEM;
 
 extern int errno;
 
-static R_FD dfd;
-static int bs = 0, skip;
+static R_FD *dfd;
 static char *sysfile = NULL;
 
 static char *acqStatus[][2] = {
@@ -29,6 +29,8 @@ static char *acqStatus[][2] = {
     NULL, NULL,
 };
 
+extern char *strErrno();
+
 int demonopen(char *system, int reclen)
 {
     if (reclen == 0)
@@ -46,7 +48,12 @@ int demonopen(char *system, int reclen)
 
     sprintf(sysfile, "%s:/dev/mon", system);
 
-    dfd = r_open(sysfile, O_MONDEV_SAMPLE);
+    if ((dfd = r_open(sysfile, R_FD_PROT_RPCTCP | O_MONDEV_SAMPLE)) == NULL)
+    {
+	fprintf(stderr, "Unable to open VME file %s.\n", sysfile);
+	return -1;
+    }
+	
     if (FD(dfd) < 0)
     {
 	r_close(dfd);
@@ -54,9 +61,9 @@ int demonopen(char *system, int reclen)
 	return -1;
     }
 
-    bs = reclen;
+    init_read_from_pipe(reclen);
 
-    if (CL(dfd) && r_tie(&dfd,bs) < 0)
+    if (CL(dfd) && r_tie(dfd,reclen) < 0)
     {
 	r_close(dfd);
 	fprintf(stderr, "Unable to make TCP/IP connection to VME system.\n");
@@ -64,12 +71,11 @@ int demonopen(char *system, int reclen)
     }
 
     if (DBX_val >= 5)
-	fprintf(stderr, "Opened %s on fd %d.\n", sysfile, FD(dfd));
+	fprintf(stderr, "Opened %s on fd %d and TCP fds %d and %d.\n", sysfile,
+		FD(dfd), SCKCTL(dfd), SCKDAT(dfd));
 
     sprintf(sysfile, "%s:/dev/acq", system);
 
-    skip = 0;
-
     return 0;
 }
 
@@ -87,6 +93,21 @@ int demonclose(void)
     return 0;
 }
 
+int demonread(int buflen, char *buffer)
+{
+    int n;
+
+    /* We bypass r_read as we need to be able to abort system calls */
+    if ((n = read_block_from_pipe(SCKDAT(dfd), buffer, buflen)) == -1)
+    {
+	if (errno != EINTR && errno != ENOSPC)
+	    perror("demonread");
+    }
+
+    return n;
+}
+
+#if 0
 int demonread(int buflen, char *buffer)
 {
     int n, len, slen;
@@ -101,14 +122,14 @@ int demonread(int buflen, char *buffer)
 	    return -1;
 
 	FD_ZERO(&fds);
-	FD_SET(SCK(dfd), &fds);
+	FD_SET(SCKDAT(dfd), &fds);
 	timeout.tv_sec = 0;
 	timeout.tv_usec = 100000;
-	select(SCK(dfd)+1, &fds, NULL, NULL, &timeout);
-	if (FD_ISSET(SCK(dfd), &fds))
+	select(SCKDAT(dfd)+1, &fds, NULL, NULL, &timeout);
+	if (FD_ISSET(SCKDAT(dfd), &fds))
 	{
 	    /* We bypass r_read as we need to be able to abort system calls */
-	    if ((n = read(SCK(dfd), buffer, len)) < 0)
+	    if ((n = read(SCKDAT(dfd), buffer, len)) < 0)
 	    {
 		if (errno == EINTR)
 		    continue;
@@ -128,14 +149,14 @@ int demonread(int buflen, char *buffer)
 	    return -1;
 
 	FD_ZERO(&fds);
-	FD_SET(SCK(dfd), &fds);
+	FD_SET(SCKDAT(dfd), &fds);
 	timeout.tv_sec = 0;
 	timeout.tv_usec = 100000;
-	select(SCK(dfd)+1, &fds, NULL, NULL, &timeout);
-	if (FD_ISSET(SCK(dfd), &fds))
+	select(SCKDAT(dfd)+1, &fds, NULL, NULL, &timeout);
+	if (FD_ISSET(SCKDAT(dfd), &fds))
 	{
 	    /* We bypass r_read as we need to be able to abort system calls */
-	    if ((n = read(SCK(dfd), buffer, len)) < 0)
+	    if ((n = read(SCKDAT(dfd), buffer, len)) < 0)
 	    {
 		if (errno == EINTR)
 		    continue;
@@ -157,15 +178,16 @@ int demonread(int buflen, char *buffer)
 	return -1;
     return slen - len;
 }
+#endif
 
 void demonstatus(void)
 {
     struct acqShDev ret;
     char *(*str)[2];
     int s;
-    R_FD fd;
+    R_FD *fd;
 
-    fd = r_open(sysfile, O_MONDEV_SAMPLE);
+    fd = r_open(sysfile, R_FD_PROT_RPC | O_MONDEV_SAMPLE);
     if (FD(fd) < 0)
     {
 	r_close(fd);
@@ -185,10 +207,7 @@ void demonstatus(void)
     fprintf(stderr,"\n");
     fprintf(stderr,"errno = 0x%08x",ret.errno);
     if( ret.errno )
-    {
-	extern char *strErrno();
         fprintf(stderr," (%s)",strErrno(ret.errno));
-    }
 
     fprintf(stderr,"\n");
 
