@@ -1192,146 +1192,157 @@ load_EG_spectrum(
 #define SPEC_SIZE_1D_GUESS 4096
 #define SPEC_SIZE_2D_GUESS 128
 int
-load_XY_spectrum(
+load_XY_spectrum
 #if NeedFunctionPrototype
-		 FILE	*fp,
-		 char	*name,
-		 int	type,
-		 int	nos,
-		 int	add)
+( FILE *fp, char *name, int type, int nos, int add)
 #else
-      fp,name,type,nos,add)
-      FILE	*fp;
-      char	*name;
-      int	type;
-      int	nos;
-	int	add;
+(fp,name,type,nos,add)
+FILE	*fp;
+char	*name;
+int	type;
+int	nos;
+int	add;
 #endif
 {
-	spec_1d_t	*p1d;
-	spec_2d_t	*p2d;
-	char		sbuf[MED_SUNSORT_BUFFER];
-	int		x_ch,y_ch,counts;
-	int 		range;
-	int		t_range = 0;
-
-/* check spectrum format by reading first line of file which should be a header 
-   in the form=>	 #X-Y ?D spectrum named ????? */
-	if ( fgets(sbuf,MED_SUNSORT_BUFFER-1,fp) == NULL || strncmp(sbuf,"#X-Y",4) != 0) {
-		fprintf(stderr,"server: #X-Y header not found during XY load from file");
-		return(SORT_NOS_ERR);
+    spec_1d_t *p1d;
+    spec_2d_t *p2d;
+    char sbuf[MED_SUNSORT_BUFFER];
+    int x_ch,y_ch,counts;
+    int range;
+    int t_range = 0;
+    
+    /* check spectrum format by reading first line of file which should be a
+       header in the form=>	 #X-Y ?D spectrum named ????? */
+    if ( fgets(sbuf,MED_SUNSORT_BUFFER-1,fp) == NULL ||
+	 strncmp(sbuf,"#X-Y",4) != 0) {
+	fprintf(stderr,"server: #X-Y header not found during XY load from "
+		"file");
+	return SORT_NOS_ERR;
+    }
+    
+    /* update data storage according to whether we are dealing with 1d or 2d
+       case*/
+    switch(type) {
+    case 1:				/* 1d case */
+	/* check that an entry already exists for this spectrum number ...
+	   if not make it */
+	if ( (p1d = tab_1d[nos]) == 0) {
+	    if (make_1d(nos,(float) SPEC_SIZE_1D_GUESS,name)) {
+		fprintf(stderr,"server: make_1d failed for 1d spectrum nos "
+			"%d from file",nos);
+		return SORT_FAIL;
+	    }
+	    p1d = tab_1d[nos];
 	}
+	else {
+	    /* clear spectrum of present data if not adding*/
+	    if (!add) 
+		for( x_ch=0; x_ch < p1d->sp->size; x_ch++)
+		    p1d->data[x_ch] = 0;
+	}
+	range = p1d->sp->size;
 
-/* update data storage according to whether we are dealing with 1d or 2d case*/
-      switch(type) {
-	 case 1:				/* 1d case */
-/* check that an entry already exists for this spectrum number ... if not make it */
-	    if ( (p1d = tab_1d[nos]) == 0) {
-		  if (make_1d(nos,(float) SPEC_SIZE_1D_GUESS,name)) {
-		  	fprintf(stderr,"server: make_1d failed for 1d spectrum nos %d from file",nos);
-		  	return(SORT_FAIL);
-		  }
-		  p1d = tab_1d[nos];
-	    }
-	    else {
-/* clear spectrum of present data if not adding*/
-		  if ( ! add) 
-			for( x_ch=0; x_ch < p1d->sp->size; x_ch++)
-		    		p1d->data[x_ch] = 0;
-	    }
-	    range = p1d->sp->size;
-
-/* read in data line by line */	    
-	    while( fscanf(fp,"%d %d",&x_ch,&counts) == 2) {
-	   	t_range = MAX(t_range,x_ch);
-/* check to see whether the disk spectra size is larger than the present allocated storage */
-		if ( t_range >= range) {
-		      t_range *= 2;
-		      p1d->data = (int *) remap_1d_spectrum(p1d, t_range);
-		   	if (! p1d->data) {
-				fprintf(stderr,"server: load_XY_file remap error during load from");
-				return(SORT_FAIL);
-		   	}
-		   	range = t_range; 
-	        }
-	        p1d->data[x_ch] += counts;
-	    }
-
-/* update spectrum data structure */
-	    p1d->sp->size = range;
-	    strcpy(p1d->sp->name,name);
-	    p1d->version = ++p1d->sp->version;	    
-	    fprintf(stderr,"server: spectrum %s loaded into 1d spectrum nos %d from file",name,nos);
-	    break;
-		    
-	case 2:				/* 2d case */
-/* check that an entry already exists for this spectrum number ... if not make it */
-	    if ( (p2d = tab_2d[nos]) == 0) {
-		  if ( make_2d(nos,(float) SPEC_SIZE_2D_GUESS,name)) {	
-			fprintf(stderr,"server: make_2d failed for 2d spectrum nos %d from file",nos);
-			return(SORT_FAIL);
-		  }
-		  p2d = tab_2d[nos];
-	    }
-	    else {
-/* clear spectrum of present data */
-		if ( ! add)
-			for( y_ch=0; y_ch < p2d->sp->size; y_ch++)
-				for( x_ch=0; x_ch < p2d->sp->size; x_ch++)
-					p2d->data[x_ch*p2d->sp->size + y_ch] = 0;
-	    }
-	    range = p2d->sp->size;
-
-/* read data in from file line by line */
-	    while (fscanf(fp,"%d %d %d",&x_ch,&y_ch,&counts) == 3) {
-	    	t_range = MAX(t_range,x_ch);
-	    	t_range = MAX(t_range,y_ch);
-/* check to see whether the disk spectra size is larger than the present allocated storage */
-		if ( t_range >= range ) {
-			  int *tptr,x,y;		/* NB declaration of variables */
-			  t_range *= 2;                 /* spectrum may well get bigger still */
-/* allocate temp memory buffer */
-			  tptr = (int *) calloc((unsigned) range*range, sizeof(int));
-			  if (! tptr) {
-				perror("sort=> load_XY_file");
-				fprintf(stderr,"server: during load from file");
-				return(SORT_FAIL);
-			  }
-/* copy data into temp memory buffer */			  
-			  (void) memcpy(tptr, p2d->data, range*range*sizeof(int));
-/* resize memory spectrum file  */	  
-			  p2d->data = (int *) remap_2d_spectrum(p2d, t_range);
-			  if (! p2d->data) {
-				fprintf(stderr,"server: remap_2d_spectrum error during load from file");
-				free(tptr);
-				return(SORT_FAIL);
-			  }
-/* copy data from old storage region into new storage */
-			  for(y=0; y < range; y++)
-			  	for(x=0; x < range; x++)
-			  		p2d->data[y + x*t_range] = tptr[y + x*t_range];
-			  range = t_range;
-			  free(tptr);
+	/* read in data line by line */	    
+	while( fscanf(fp,"%d %d",&x_ch,&counts) == 2) {
+	    t_range = MAX(t_range,x_ch);
+	    /* check to see whether the disk spectra size is larger than the
+	       present allocated storage */
+	    if ( t_range >= range) {
+		int ran;
+		ran = range*2;
+		p1d->data = (int *) remap_1d_spectrum(p1d, ran);
+		if (!p1d->data) {
+		    fprintf(stderr,"server: load_XY_file remap error during "
+			    "load from");
+		    return SORT_FAIL;
 		}
-		p2d->data[y_ch + x_ch*range] += counts;
+		range = ran; 
 	    }
-
-/* update spectrum data structure */
-	    p2d->sp->size = range;
-	    strcpy(p2d->sp->name,name);
-	    p2d->version = ++p2d->sp->version;
-	    if (name[0] == 'w' || name[0] == 'W')		
-		  p2d->sp->win = p2d->win = 1;
-	    else
-		  p2d->sp->win = p2d->win = 0;
-	    fprintf(stderr,"server: spectrum %s loaded into 2d spectrum nos %d from file",name,nos);
-	    break;
-	    
-	default:
-	    fprintf(stderr,"server: unrecognised type = %d during load from file",type);
-	    return(SORT_FAIL);
+	    p1d->data[x_ch] += counts;
 	}
-	return(0);
+	
+	/* update spectrum data structure */
+	p1d->sp->size = range;
+	strcpy(p1d->sp->name,name);
+	p1d->version = ++p1d->sp->version;	    
+	fprintf(stderr,"server: spectrum %s loaded into 1d spectrum nos %d "
+		"from file",name,nos);
+	break;
+	
+    case 2:				/* 2d case */
+	/* check that an entry already exists for this spectrum number ...
+	   if not make it */
+	if ( (p2d = tab_2d[nos]) == 0) {
+	    if ( make_2d(nos,(float) SPEC_SIZE_2D_GUESS,name)) {	
+		fprintf(stderr,"server: make_2d failed for 2d spectrum nos "
+			"%d from file",nos);
+		return SORT_FAIL;
+	    }
+	    p2d = tab_2d[nos];
+	}
+	else {
+	    /* clear spectrum of present data */
+	    if ( ! add)
+		for( y_ch=0; y_ch < p2d->sp->size; y_ch++)
+		    for( x_ch=0; x_ch < p2d->sp->size; x_ch++)
+			p2d->data[x_ch*p2d->sp->size + y_ch] = 0;
+	}
+	range = p2d->sp->size;
+	
+	/* read data in from file line by line */
+	while (fscanf(fp,"%d %d %d",&x_ch,&y_ch,&counts) == 3) {
+	    t_range = MAX(t_range,x_ch);
+	    t_range = MAX(t_range,y_ch);
+	    /* check to see whether the disk spectra size is larger than the
+	       present allocated storage */
+	    if ( t_range >= range ) {
+		int *tptr,x,y,ran; /* NB declaration of variables */
+		ran = range*2; /* spectrum may well get bigger still */
+		/* allocate temp memory buffer */
+		tptr = (int *) calloc((unsigned) range*range, sizeof(int));
+		if (! tptr) {
+		    perror("sort=> load_XY_file");
+		    fprintf(stderr,"server: during load from file");
+		    return SORT_FAIL;
+		}
+		/* copy data into temp memory buffer */			  
+		(void) memcpy(tptr, p2d->data, range*range*sizeof(int));
+		/* resize memory spectrum file  */	  
+		p2d->data = (int *) remap_2d_spectrum(p2d, ran);
+		if (! p2d->data) {
+		    fprintf(stderr,"server: remap_2d_spectrum error during "
+			    "load from file");
+		    free(tptr);
+		    return SORT_FAIL;
+		}
+		/* copy data from old storage region into new storage */
+		for(y=0; y < range; y++)
+		    for(x=0; x < range; x++)
+			p2d->data[y + x*ran] = tptr[y + x*range];
+		range = ran;
+		free(tptr);
+	    }
+	    p2d->data[y_ch + x_ch*range] += counts;
+	}
+
+	/* update spectrum data structure */
+	p2d->sp->size = range;
+	strcpy(p2d->sp->name,name);
+	p2d->version = ++p2d->sp->version;
+	if (name[0] == 'w' || name[0] == 'W')		
+	    p2d->sp->win = p2d->win = 1;
+	else
+	    p2d->sp->win = p2d->win = 0;
+	fprintf(stderr,"server: spectrum %s loaded into 2d spectrum nos %d "
+		"from file",name,nos);
+	break;
+	
+    default:
+	fprintf(stderr,"server: unrecognised type = %d during load from file",
+		type);
+	return SORT_FAIL;
+    }
+    return 0;
 }
 
 
