@@ -28,6 +28,7 @@
 #include "sort_mem.h"
 #include "datatape.h"
 #include "../sunsort_lib/formats.h"
+#include "data_pipe.h"
 #include "demon.h"
 #include "read_spec.h"
 #include "discsubs.h"
@@ -70,101 +71,121 @@ static char actionchar = 'Y';
  * NB read tape doesn't require a tape format specifying
  */
 int
-open_sort_file(
+open_sort_file
 #if NeedFunctionPrototype
-	   char *opt_str, char *reply)
+(char *opt_str, char *reply)
 #else
-      opt_str, reply)
-      char     *opt_str;
-      char     *reply;
+(opt_str, reply)
+char *opt_str;
+char *reply;
 #endif
 {
-      char   source[BUFSIZ], read_file[BUFSIZ];
-      sort_IO_t   *ptr = sort_io_data;
+    char source[BUFSIZ], read_file[BUFSIZ], *rf;
+    int comm;
+    sort_IO_t   *ptr = sort_io_data;
       
-      if (DBX_val >= 5)
-	    fprintf(stderr,"server: open_sort_file called with arg %s\n",opt_str);
-
-/* check that not trying to sort */      
-      if (Sorting_data(0) != SORT_FALSE) {
-	    sprintf(reply,"invalid command while sorting\n");
-	    return(SORT_FALSE);
-      }
+    if (DBX_val >= 5)
+	fprintf(stderr, "server: open_sort_file called with arg %s\n",
+		opt_str);
+    
+    /* check that not trying to sort */      
+    if (Sorting_data(0) != SORT_FALSE) {
+	sprintf(reply, "invalid command while sorting\n");
+	return SORT_FALSE;
+    }
+    
+    /* make sure we haven't already got a read file open */		  
+    if ( ptr->IO_state & READING_IN) {
+	sprintf(reply, "OPEN command issued with %s already open!\n",
+		ptr->read_file);
+	return SORT_FALSE;
+    }
+    if ( sscanf(opt_str, "%s %n%s", source, &comm, read_file) < 2) {
+	sprintf(reply, "invalid command line for OPEN command => %s\n",
+		opt_str);
+	return SORT_FALSE;
+    }
+    rf = read_file;
+    if (strncmp(source, "disk", 4) == 0) {
+	/* open disk run file */			
+	if (ddopen(read_file, READ_MODE, IOfmt.rdisk_blen, IOfmt.rdisk_rlen)
+	    == -1) {
+	    sprintf(reply, "error whilst opening disk file %s\n", read_file);
+	    return SORT_FALSE;
+	} 
+	ptr->IO_state |= READING_DISK;
+	ptr->sort_media = (short) DISK_DATA;
+	sprintf(reply, "disk file %s open\n", read_file);
+    }		  
+    else if (strncmp(source, "tape", 4) == 0) {
+	int tape_opt = 0;
+	if (!(ptr->IO_state & R_TAPE_MOUNTED)) {
+	    sprintf(reply, "tape not mounted for OPEN\n");
+	    return SORT_FALSE;
+	}
+	/* check to see if rewind or hold options set */
+	if (source[4] == '/') {
+	    if (isdigit((int) source[5]))
+		sscanf(source, "tape/%d", &tape_opt);
+	    if (DBX_val >= 5)
+		fprintf(stderr, "server: tape option = %d\n", tape_opt);
+	}
+	/* open tape run file */
+	(void) Stop_interupt(SORT_SET, SORT_FALSE);
+	if (dtopen(read_file, READ_MODE, IOfmt.rtape_blen, IOfmt.rtape_rlen, 
+		   tape_opt)) {
+	    sprintf(reply, "error whilst opening tape file %s\n", read_file);
+	    return SORT_FALSE;
+	} 
+	ptr->IO_state |= READING_TAPE;
+	ptr->sort_media = (short) EXABYTE_DATA;
+	sprintf(reply, "tape file %s open\n", read_file);
+    }
+    else if (strncmp(source, "remote", 6) == 0) {
+	/* open tape run file */			
+	if ( remote_op(OPEN_REMOTE) == -1) {
+	    sprintf(reply, "error whilst opening remote stream\n");
+	    return SORT_FALSE;
+	} 
+	ptr->IO_state |= READING_REMOTE;
+	ptr->sort_media = (short) REMOTE_DATA;
+	sprintf(reply, "Remote read source open\n");
+	strcpy(read_file, "REMOTE");
+    }
+    else if (strncmp(source, "demon", 5) == 0) {
+	if (demonopen(read_file, IOfmt.rdisk_rlen))
+	{
+	    sprintf(reply, "Error whilst opening Demon data feed from %s.\n", 
+		    read_file);
+	    return SORT_FALSE;
+	}
+	sprintf(reply, "Demon data feed from %s open.\n", read_file);
+	ptr->IO_state |= READING_DEMON;
+	ptr->sort_media = (short) DEMON_DATA;
+    }
+    else if (strncmp(source, "pipe", 4) == 0) {
+	rf = opt_str + comm;
+	if (pipeopen(rf, IOfmt.rdisk_rlen))
+	{
+	    sprintf(reply, 
+		    "Error whilst opening pipe from \"%s\".\n", rf);
+	    return SORT_FALSE;
+	}
+	sprintf(reply, "Pipe from \"%s\" open.\n", rf);
+	ptr->IO_state |= READING_PIPE;
+	ptr->sort_media = (short) PIPE_DATA;
+    }
+    else {
+	sprintf(reply, "error during OPEN command => %s\n", opt_str);
+	return SORT_FALSE;
+    }
+    
+    strncpy(ptr->read_file, rf, MED_SUNSORT_BUFFER);
+    ptr->read_file[MED_SUNSORT_BUFFER] = '\0';
+    *sorted_records = 0;
       
-/* make sure we haven't already got a read file open */		  
-      if ( ptr->IO_state & READING_IN) {
-	    sprintf(reply,"OPEN command issued with %s already open!\n",ptr->read_file);
-	    return(SORT_FALSE);
-      }
-      if ( sscanf(opt_str,"%s %s",source,read_file) < 2) {
-	    sprintf(reply,"invalid command line for OPEN command => %s\n",opt_str);
-	    return(SORT_FALSE);
-      }
-      
-      if (strncmp(source,"disk",4) == 0) {
-	    /* open disk run file */			
-	    if ( ddopen(read_file,READ_MODE,IOfmt.rdisk_blen,IOfmt.rdisk_rlen) == -1) {
-		  sprintf(reply,"error whilst opening disk file %s\n",read_file);
-		  return(SORT_FALSE);
-	    } 
-	    ptr->IO_state |= READING_DISK;
-	    ptr->sort_media = (short) DISK_DATA;
-	    sprintf(reply,"disk file %s open\n",read_file);
-      }		  
-      else if (strncmp(source,"tape",4) == 0) {
-	    int tape_opt = 0;
-	    if ( ! (ptr->IO_state & R_TAPE_MOUNTED)) {
-		  sprintf(reply,"tape not mounted for OPEN\n");
-		  return(SORT_FALSE);
-	    }
-	    /* check to see if rewind or hold options set */
-	    if (source[4] == '/') {
-		  if (isdigit((int) source[5]))
-			sscanf(source,"tape/%d",&tape_opt);
-		  if (DBX_val >= 5) fprintf(stderr,"server: tape option = %d\n",tape_opt);
-	    }
-	    /* open tape run file */
-	    (void) Stop_interupt(SORT_SET, SORT_FALSE);
-	    if ( dtopen(read_file,READ_MODE,IOfmt.rtape_blen,IOfmt.rtape_rlen,tape_opt)) {
-		  sprintf(reply,"error whilst opening tape file %s\n",read_file);
-		  return(SORT_FALSE);
-	    } 
-	    ptr->IO_state |= READING_TAPE;
-	    ptr->sort_media = (short) EXABYTE_DATA;
-	    sprintf(reply,"tape file %s open\n",read_file);
-      }
-      else if (strncmp(source,"remote",6) == 0) {
-	    /* open tape run file */			
-	    if ( remote_op(OPEN_REMOTE) == -1) {
-		  sprintf(reply,"error whilst opening remote stream\n");
-		  return(SORT_FALSE);
-	    } 
-	    ptr->IO_state |= READING_REMOTE;
-	    ptr->sort_media = (short) REMOTE_DATA;
-	    sprintf(reply,"Remote read source open\n");
-	    strcpy(read_file,"REMOTE");
-      }
-      else if (strncmp(source,"demon",5) == 0) {
-	  if (demonopen(read_file, IOfmt.rdisk_rlen))
-	  {
-	      sprintf(reply, "Error whilst opening Demon data feed from %s.\n",
-		      read_file);
-	      return(SORT_FALSE);
-	  }
-	  sprintf(reply, "Demon data feed from %s open.\n", read_file);
-	  ptr->IO_state |= READING_DEMON;
-	  ptr->sort_media = (short) DEMON_DATA;
-      }
-      else {
-	    sprintf(reply,"error during OPEN command => %s\n",opt_str);
-	    return(SORT_FALSE);
-      }
-      strncpy(ptr->read_file,read_file,MED_SUNSORT_BUFFER);
-      ptr->read_file[MED_SUNSORT_BUFFER] = '\0';
-      *sorted_records = 0;
-      
-      fprintf(stderr,"*** %s",reply);
-      return(SORT_TRUE);
+    fprintf(stderr, "*** %s", reply);
+    return SORT_TRUE;
 }
 
 /*
@@ -220,6 +241,10 @@ close_sort_file(
 	  demonclose();
 	  ptr->IO_state &= (~READING_DEMON);
       }
+      else if (ptr->IO_state & READING_PIPE) {
+	  pipeclose();
+	  ptr->IO_state &= (~READING_PIPE);
+      }
       else {
 	    sprintf(reply,"CLOSE command issued with no read file open\n");
 	    return(SORT_FALSE);
@@ -976,64 +1001,69 @@ overlay_1d(
       return(Display_1d(opt_str, reply));
 }
 
-int Display_2d(
+int Display_2d
 #if NeedFunctionPrototype
-	   char *opt_str, char *reply)
+(char *opt_str, char *reply, int window)
 #else
-      opt_str, reply)
-      char     *opt_str;
-      char     *reply;
+(opt_str, reply, window)
+char *opt_str;
+char *reply;
+int window;
 #endif
 {
-      spec_2d_t	        **pp2d;
-      int		nos;
-      int		size;
-      
-      if (DBX_val >= 5)
-	    fprintf(stderr,"server: Display_2d called with arg %s\n",opt_str);
+    spec_2d_t **pp2d;
+    int nos;
+    int size;
+    
+    if (DBX_val >= 5)
+	fprintf(stderr,"server: Display_2d called with arg %s\n",opt_str);
 
-/* check that graphics process is alive */
-      if (! graf_proc2_OK) {
-	    sprintf(reply,"2d graphics process not running\n"); 
-	    return(SORT_FALSE);
-      }
-
-/* pass information on display processes ids */      
-      pshm->pid_1d = graf_1d_pid;
-      pshm->pid_2d = graf_2d_pid;
+    /* check that graphics process is alive */
+    if (! graf_proc2_OK) {
+	sprintf(reply,"2d graphics process not running\n"); 
+	return SORT_FALSE;
+    }
+    
+    /* pass information on display processes ids */      
+    pshm->pid_1d = graf_1d_pid;
+    pshm->pid_2d = graf_2d_pid;
       
-/* decode option string */
-      if ( sscanf(opt_str,"%d",&nos) != 1) {
-	    sprintf(reply,"no valid spectrum number provided to Display2d\n");
-	    return(SORT_FALSE);
-      }
+    /* decode option string */
+    if ( sscanf(opt_str,"%d",&nos) != 1) {
+	sprintf(reply,"no valid spectrum number provided to Display2d\n");
+	return SORT_FALSE;
+    }
 	  
-/* get pointer to spectrum storage table */
-      pp2d = get_nametab_2d();
-      if ( nos >= TAB_SIZE_2D || nos <= 0 || (! pp2d[nos])) {
-	    sprintf(reply,"no data associated with 2d spectrum number %d\n",nos);
-	    return(SORT_FALSE);
-      }
+    /* get pointer to spectrum storage table */
+    pp2d = get_nametab_2d();
+    if ( nos >= TAB_SIZE_2D || nos <= 0 || (! pp2d[nos])) {
+	sprintf(reply,"no data associated with 2d spectrum number %d\n",nos);
+	return SORT_FALSE;
+    }
       
-/* copy spectrum data into memory segment */
-      (void) strcpy(pshm->name,pp2d[nos]->sp->name);
-      pshm->size = size = pp2d[nos]->sp->size;
-      
-      size = size*size;
-      size = (size > SHM_ARRAY_SIZE) ? SHM_ARRAY_SIZE : size;
-      (void) memcpy((char *)pshm->array, (char *)pp2d[nos]->data, sizeof(int)*size);
+    /* copy spectrum data into memory segment */
+    (void) strcpy(pshm->name,pp2d[nos]->sp->name);
+    pshm->size = size = pp2d[nos]->sp->size;
+    
+    size = size*size;
+    size = (size > SHM_ARRAY_SIZE) ? SHM_ARRAY_SIZE : size;
+    memcpy((char *)pshm->array, (char *)pp2d[nos]->data, sizeof(int)*size);
 
-/* non ipc system */
-	if ( write_to_pipe(".SORT_pipe",size) == SORT_FAIL) 
-		sprintf(reply,"error during writing of data to graf process\n");
+    /* non ipc system */
+    if ( write_to_pipe(window ? ".SORT_pipe_W" : ".SORT_pipe", size)
+	 == SORT_FAIL) 
+	sprintf(reply,"error during writing of data to graf process\n");
 
-/* signal graphics process to read shared memory segment and display */
+    /* signal graphics process to read shared memory segment and display */
+    if (!window)
+    {
 	if (kill(graf_2d_pid,SIGUSR2) == -1)
-		perror("Display_2d SIGUSR2");
-
-      displayed_spectrum[MAX_SPEC_DISPLAY+1] = nos;
-      sprintf(reply,"\n");
-      return(SORT_TRUE);
+	    perror("Display_2d SIGUSR2");
+	
+	displayed_spectrum[MAX_SPEC_DISPLAY+1] = nos;
+    }
+    sprintf(reply,"\n");
+    return SORT_TRUE;
 }
 
 int
@@ -1049,7 +1079,7 @@ display_2d(
       if (DBX_val >= 5)
 	    fprintf(stderr,"server: Display_2d called with arg %s\n",opt_str);
       (void) strcpy(pshm->com_str,"DISPLAY 2");
-      return(Display_2d(opt_str,reply));
+      return(Display_2d(opt_str,reply,0));
 }
 
 /*
@@ -1130,229 +1160,56 @@ clear_spectra(
  *   request the display of a 2d spectrum on which to create a 2d window
  */
 int
-setwindow(
+setwindow
 #if NeedFunctionPrototype
-	   char *opt_str, char *reply)
+(char *opt_str, char *reply)
 #else
-      opt_str, reply)
-      char     *opt_str;
-      char     *reply;
+(opt_str, reply)
+char *opt_str;
+char *reply;
 #endif
 {
-      int  win_nos;
-      int  spec_nos;
-      spec_2d_t	**pp2d;
+    int  win_nos;
+    int  spec_nos;
+    spec_2d_t	**pp2d;
       
-      if (DBX_val >= 5)
-	    fprintf(stderr,"server: setwindow called with arg %s\n",opt_str);
-      
-      if (Sorting_data(0) != SORT_FALSE) {
-	    sprintf(reply,"invalid command while sorting\n");
-	    return(SORT_FALSE);
-      }
-
-/* decode option string */
-      if (sscanf(opt_str,"%d on %d", &win_nos, &spec_nos) !=2) {
-	    sprintf(reply,"invalid options string in set window call\n");
-	    return(SORT_FALSE);
-      }
-
+    if (DBX_val >= 5)
+	fprintf(stderr,"server: setwindow called with arg %s\n",opt_str);
+    
+    if (Sorting_data(0) != SORT_FALSE) {
+	sprintf(reply,"invalid command while sorting\n");
+	return SORT_FALSE;
+    }
+    
+    /* decode option string */
+    if (sscanf(opt_str,"%d on %d", &win_nos, &spec_nos) !=2) {
+	sprintf(reply,"invalid options string in set window call\n");
+	return SORT_FALSE;
+    }
+    
 /* check that spectrum number refers to 2d window */
-      pp2d = get_nametab_2d();
-      if (win_nos > 0 && win_nos < TAB_SIZE_2D) {
-	    if ( ! pp2d[win_nos]) {
-		  sprintf(reply,"no data associated with 2d spectrum number %d\n",win_nos);
-		  return(SORT_FALSE);
-	    }
-	    if (pp2d[win_nos]->win == 0) {
-		  sprintf(reply,"2d spectrum %d is not a window!\n",win_nos);
-		  return(SORT_FALSE);
-	    }
-	    (void) strcpy(pshm->com_str,"WINDOW 3");
-	    pshm->win2d = win_nos;
-	    (void) sprintf(opt_str,"%d",spec_nos);
-	    return(Display_2d(opt_str,reply));
-      }
-      sprintf(reply,"window number %d outside possible range\n",win_nos);
-      return(SORT_FAIL);
-}
-
-#define INSIDE  1
-#define OUTSIDE 2
-int
-viewwindow(
-#if NeedFunctionPrototype
-	   char *opt_str, char *reply)
-#else
-      opt_str, reply)
-      char     *opt_str;
-      char     *reply;
-#endif
-{
-      int           wnos, *wdata;
-      int           nos,  *data;
-      spec_2d_t	    **pp2d;
-      int	    array[SHM_ARRAY_SIZE];
-      int           keydata = INSIDE;
-      int           size;
-      int           array_size;
-      register int  i,j;
- 
-      if (DBX_val >= 5)
-	    fprintf(stderr,"server: showwindow called with arg %s\n",opt_str);
-
-/* check that graphics process is alive */
-      if (! graf_proc2_OK) {
-	    sprintf(reply,"2d graphics process not running\n"); 
-	    return(SORT_FALSE);
-      }
-
-/* pass information on display processes ids */      
-      pshm->pid_1d = graf_1d_pid;
-      pshm->pid_2d = graf_2d_pid;
-      
-/* decode option string */
-      if (sscanf(opt_str,"%d inside %d", &wnos, &nos) !=2) {
-	    keydata = OUTSIDE;
-	    if (sscanf(opt_str,"%d outside %d", &wnos, &nos) !=2) {
-		  sprintf(reply,"invalid options string in set window call\n");
-		  return(SORT_FALSE);
-	    }
-      }
-      
-/* check that wnos corresponds to a 2d window */
-      pp2d = get_nametab_2d();
-      if (wnos <= 0 || wnos >= TAB_SIZE_2D) {
-	    sprintf(reply,"window number %d outside possible range\n",wnos);
-	    return(SORT_FAIL);
-      }
-      if ( ! pp2d[wnos]) {
-	    sprintf(reply,"no data associated with 2d spectrum number %d\n",wnos);
-	    return(SORT_FALSE);
-      }
-      if (pp2d[wnos]->win == 0) {
-	    sprintf(reply,"2d spectrum %d is not a window!\n",wnos);
-	    return(SORT_FALSE);
-      }
-
-/* check that nos corresponds to a real 2d spectrum */
-      if (nos <= 0 || nos >= TAB_SIZE_2D) {
-	    sprintf(reply,"spectrum number %d outside possible range\n",nos);
-	    return(SORT_FAIL);
-      }
-      if ( ! pp2d[nos]) {
-	    sprintf(reply,"no data associated with 2d spectrum number %d\n",nos);
-	    return(SORT_FALSE);
-      }
-
-/* define pointers to spectrum and window data */
-      data = pp2d[nos]->data;
-      wdata = pp2d[wnos]->data;	
-
-/* let's worry about the possiblity that the 2D spectrum and the window are 
-not the same size...if they are not use array to give them the same dimensions*/
-      if ( pp2d[nos]->sp->size != pp2d[wnos]->sp->size) {
-	    if ( pp2d[nos]->sp->size > pp2d[wnos]->sp->size) {
-		  /* copy 2D window into array */
-		  size = pp2d[nos]->sp->size;
-		  array_size = size * size;
-		  for (i=j=0; i < array_size; j = i++ % size) 
-			array[i] = (j >= pp2d[wnos]->sp->size) ? 0 : wdata[i];
-		  wdata = array;
-	    }
-	    else {
-		  /* copy 2d spectrum into array */
-		  size = pp2d[wnos]->sp->size;
-		  array_size = size * size;
-		  for (i=j=0; i < array_size; j = i++ % size) 
-			array[i] = (j >= pp2d[nos]->sp->size) ? 0 : data[i];
-		  data = array;
-	    }
-      }
-      /* window and spectrum are the same size */
-      else {
-	    size = pp2d[nos]->sp->size;
-	    array_size = size * size;
-      }
-      
-/* set size to be appropriate for the data storage array */
-      array_size = (array_size > SHM_ARRAY_SIZE) ? SHM_ARRAY_SIZE : array_size;
-
-/* copy window and spectrum data into array */
-      if (keydata == INSIDE) {
-	    for (i=0; i < array_size; i++) 
-		  array[i] = (wdata[i] == 0) ? 321 : data[i];
-      }
-      else if (keydata == OUTSIDE) {
-	    for (i=0; i < array_size; i++) 
-		  array[i] = (wdata[i] == 0) ? data[i] : 321;
-      }
-      else {
-	    sprintf(reply,"error decoding window menu choice\n");
-	    return(SORT_FALSE);
-      }
-      
-/* copy spectrum data into shared memory segment */     
-      (void) strcpy(pshm->com_str,"DISPLAY 2");
-      (void) strcpy(pshm->name,pp2d[nos]->sp->name);
-      pshm->win2d = wnos;
-      pshm->size = size;
-      (void) memcpy((char *)pshm->array, (char *)array, sizeof(int)*array_size);
-      
-/* non ipc system */
-      if ( write_to_pipe(".SORT_pipe",array_size) == SORT_FAIL) 
-	    sprintf(reply,"error during writing of data to graf process\n");
-
-/* signal graphics process to read shared memory segment and display */
-      if (kill(graf_2d_pid,SIGUSR2) == -1)
-	      perror("Viewwin SIGUSR2");
-      
-      sprintf(reply,"\n");
-      return(SORT_TRUE);
-}
-
-/*
- *  request the display of a 2d window spectrum
- */
-int
-showwindow(
-#if NeedFunctionPrototype
-	   char *opt_str, char *reply)
-#else
-      opt_str, reply)
-      char     *opt_str;
-      char     *reply;
-#endif
-{
-      int  win_nos;
-      spec_2d_t	**pp2d;
-      
-      if (DBX_val >= 5)
-	    fprintf(stderr,"server: viewwindow called with arg %s\n",opt_str);
-      
-/* decode option string */
-      if (sscanf(opt_str,"%d", &win_nos) !=1) {
-	    sprintf(reply,"invalid options string in set window call\n");
-	    return(SORT_FALSE);
-      }
-
-/* check that spectrum number refers to 2d window */
-      pp2d = get_nametab_2d();
-      if (win_nos > 0 && win_nos < TAB_SIZE_2D) {
-	    if ( ! pp2d[win_nos]) {
-		  sprintf(reply,"no data associated with 2d spectrum number %d\n",win_nos);
-		  return(SORT_FALSE);
-	    }
-	    if (pp2d[win_nos]->win == 0) {
-		  sprintf(reply,"2d spectrum %d is not a window!\n",win_nos);
-		  return(SORT_FALSE);
-	    }
-	    (void) strcpy(pshm->com_str,"DISPLAY 2");
-	    pshm->win2d = win_nos;
-	    return(Display_2d(opt_str,reply));
-      }
-      sprintf(reply,"window number %d outside possible range\n",win_nos);
-      return(SORT_FAIL);
+    pp2d = get_nametab_2d();
+    if (win_nos > 0 && win_nos < TAB_SIZE_2D) {
+	if (!pp2d[win_nos]) {
+	    sprintf(reply,"no data associated with 2d spectrum number %d\n",
+		    win_nos);
+	    return SORT_FALSE;
+	}
+	if (pp2d[win_nos]->win == 0) {
+	    sprintf(reply,"2d spectrum %d is not a window!\n",win_nos);
+	    return SORT_FALSE;
+	}
+	strcpy(pshm->com_str,"WINDOW 3");
+	sprintf(opt_str, "%d", win_nos);
+	if (Display_2d(opt_str, reply, 1) != SORT_TRUE)
+	    return SORT_FALSE;
+	strcpy(pshm->com_str,"DISPLAY 3");
+	pshm->win2d = win_nos;
+	sprintf(opt_str,"%d",spec_nos);
+	return(Display_2d(opt_str,reply,0));
+    }
+    sprintf(reply,"window number %d outside possible range\n",win_nos);
+    return(SORT_FAIL);
 }
 
 /*
@@ -2030,3 +1887,39 @@ char     *reply;
     return SORT_TRUE;
 }
 
+int
+processes
+#if NeedFunctionPrototype
+(char *opt_str, char *reply)
+#else
+(opt_str, reply)
+char     *opt_str;
+char     *reply;
+#endif
+{
+    int w;
+
+    if (DBX_val >= 5)
+	fprintf(stderr,"server: processes function called with args => %s\n",
+		opt_str);
+    
+    if (sscanf(opt_str, " %d", &w) < 1)
+    {
+	w = sysconf(_SC_NPROCESSORS_ONLN);
+	fprintf(stderr, "Running on a machine with %d processor%s.\n",
+		w, (w == 1) ? "" : "s");
+    }
+    else
+    {
+	workers = w;
+    }
+    
+    if (workers == 0)
+	sprintf(reply, "Next loadsort will match number of worker "
+		"processes to number of processors.\n");
+    else
+	sprintf(reply, "Next loadsort will use %d worker process%s.\n",
+		workers, (workers == 1) ? "" : "es");
+
+    return SORT_TRUE;
+}
