@@ -45,10 +45,10 @@
 #define REMOTE_DATA	1
 #define DISK_DATA	2
 #define DEMON_DATA	3
+#define PIPE_DATA	4
 
 #define REWIND_OPT	0x1
 #define HOLD_OPT	0x2
-#define WRITEF_OPT	0x4
 
 #define	REF_SPEC_LIST	1
 #define NEW_SPEC_LIST	0
@@ -58,23 +58,24 @@
 #define READING_REMOTE  0x2
 #define READING_TAPE	0x4
 #define READING_DEMON	0x8
-#define R_TAPE_MOUNTED	0x10
+#define READING_PIPE	0x10
+#define R_TAPE_MOUNTED	0x20
 #define READING_IN      (READING_DISK | READING_REMOTE | READING_TAPE | \
-			 READING_DEMON)
+			 READING_DEMON | READING_PIPE)
 
-#define WRITING_DISK	0x20
-#define WRITING_TAPE    0x40
-#define W_TAPE_MOUNTED  0x80
+#define WRITING_DISK	0x40
+#define WRITING_TAPE    0x80
+#define W_TAPE_MOUNTED  0x100
 #define WRITING_OUT     (WRITING_DISK | WRITING_TAPE)
 
 /* deinitions for use with IO_state  (dirs) */
-#define SAVING_DATA	0x100
-#define LOADING_DATA	0x200
-#define OVER_WRITE	0x400
-#define LOAD_N_ADD	0x800
-#define SDB_TYPE        0x1000
-#define XY_TYPE         0x2000
-#define EG_TYPE         0x4000
+#define SAVING_DATA	0x200
+#define LOADING_DATA	0x400
+#define OVER_WRITE	0x800
+#define LOAD_N_ADD	0x1000
+#define SDB_TYPE        0x2000
+#define XY_TYPE         0x4000
+#define EG_TYPE         0x8000
 #define FMT_MASK	(SDB_TYPE | XY_TYPE | EG_TYPE)
 
 /* paramters used in sort_notify.c */
