@@ -35,6 +35,7 @@
 #include "data_tape.h"
 #include "data_disk.h"
 #include "data_remote.h"
+#include "data_pipe.h"
 #include "demon.h"
 
 void read_args P((int, char** argv));
@@ -82,6 +83,7 @@ int batch_mode = SORT_FALSE;
 char *tmp_spectrum_dir = NULL;
 char *sunsort_proc = NULL;
 int DBX_val = 0;
+int workers = 1;
 
 #ifndef MAX
 #define MAX(x,y) ((int)(x) < (int)(y)) ? (y) : (x)
@@ -90,7 +92,7 @@ int DBX_val = 0;
 #define MIN(x,y) ((int)(x) > (int)(y)) ? (y) : (x)
 #endif
 
-/****************************************************************************/
+/************************************************************************/
 
 void
 main(
@@ -190,7 +192,7 @@ main(
       exit(-1);
 }
 
-/******************************************************************************/
+/************************************************************************/
 /* 
  * check whether specified string corresponds to an existing directory 
  * if it does give user the choice to over write existing files
@@ -231,7 +233,7 @@ Query_Save_directory(
 	return(0);
 }
 
-/**************************************************************************************************/
+/************************************************************************/
 void
 start_graphics(
 #if NeedFunctionPrototype
@@ -288,7 +290,7 @@ int getdtablesize(void)
 
 
 
-/******************************************************************************/
+/************************************************************************/
 /*
  *  this function is used by background threads as well
  *  so must NOT modify any STATE data
@@ -332,7 +334,7 @@ do_process(
       return(SORT_FAIL);
 }
 
-/**************************************************************************************************/
+/************************************************************************/
 
 int
 do_pipe_process
@@ -459,7 +461,7 @@ int ns, *streams;
 
 }
 
-/********************************************************************/
+/************************************************************************/
 int
 start_gui
 #if NeedFunctionPrototype
@@ -509,7 +511,7 @@ char  **argv;
 
     return(-1);
 }
-/**************************************************************************************************/
+/************************************************************************/
 int
 start_sortproc
 #if NeedFunctionPrototype
@@ -521,21 +523,24 @@ int   argc;
 char  **argv;
 #endif
 {
-    char *my_argv[100];
-    char dbx_str[24];
+    char *my_argv[100]; 
+    char dbx_str[16], work_str[16];
     int streams[3];
     int pid,i;
     
     /* copy argument list */
     my_argv[0] = process;
-    for(i=1; i<argc && i<94; i++)
+    for(i=1; i<argc && i<93; i++)
 	my_argv[i] = argv[i];
     my_argv[i] = "-sdir";
     my_argv[i+1] = tmp_spectrum_dir;
     my_argv[i+2] = "-dbx";
-    sprintf(dbx_str,"%d",DBX_val);       
+    sprintf(dbx_str, "%d", DBX_val);       
     my_argv[i+3] = dbx_str;
-    my_argv[i+4] = (char *)0;
+    my_argv[i+4] = "-workers";
+    sprintf(work_str, "%d", workers);
+    my_argv[i+5] = work_str;
+    my_argv[i+6] = NULL;
     
     /* set up stream number for new process*/
     streams[0] = SORT_SERVER_INFD;
@@ -557,7 +562,7 @@ char  **argv;
     
     return(-1);
 }
-/**************************************************************************************************/
+/************************************************************************/
 
 char *
 make_tmp_dir(
@@ -576,7 +581,7 @@ make_tmp_dir(
       return(file);
 }
 
-/**************************************************************************************************/
+/************************************************************************/
 int
 query_request(
 #if NeedFunctionPrototype
@@ -602,7 +607,7 @@ query_request(
       return(SORT_FALSE);
 }
 
-/******************************************************************************/
+/************************************************************************/
 char *
 rm_leading_blanks(
 #if NeedFunctionPrototype
@@ -621,7 +626,7 @@ rm_leading_blanks(
 	return (string + i);
 }
 
-/**************************************************************************************************/
+/************************************************************************/
 /*ARGSUSED*/
 void
 read_args(
@@ -672,7 +677,7 @@ read_args(
      return;
 }
 
-/**************************************************************************************************/
+/************************************************************************/
 void
 main_event_loop(
 #if NeedFunctionPrototype
@@ -856,79 +861,73 @@ write_reply(
 }
 
 void
-check_children(
-#if NeedFunctionPrototype
-	  void)
-#else
-      )
-#endif
+check_children P((void))
 {
-      int   statusp;
+    int   statusp;
 
 /* check sort process */
-      if (sort_proc_OK == SORT_TRUE) {
-	    if (waitpid(sort_pid,&statusp,WNOHANG) == sort_pid) {
-		  sort_proc_OK = SORT_FALSE;
-		  if (FDSIN != STDIN_FILENO) {
-			(void) close(FDSIN);
-			FDSIN = STDIN_FILENO;
-		  }
-		  if (FDSOUT != STDOUT_FILENO) {
-			(void) close(FDSOUT);
-			FDSOUT = STDOUT_FILENO;
-		  }
-		  if (FDSUSEROUT != STDOUT_FILENO) {
-			(void) close(FDSUSEROUT);
-			FDSUSEROUT = STDOUT_FILENO;
-		  }
-		  /* check to see whether there is a sort thread alive */
-		  if (Sorting_data(0) == SORT_TRUE) {
-			stop_sort_threads();
-		  }
-		  fprintf(stderr,
-			  "server: sort process has exited\n");
+    if (sort_proc_OK == SORT_TRUE) {
+	if (waitpid(sort_pid,&statusp,WNOHANG) == sort_pid) {
+	    sort_proc_OK = SORT_FALSE;
+	    kill_all_workers();
+	    
+	    if (FDSIN != STDIN_FILENO) {
+		(void) close(FDSIN);
+		FDSIN = STDIN_FILENO;
 	    }
-      }   
-
+	    if (FDSOUT != STDOUT_FILENO) {
+		(void) close(FDSOUT);
+		FDSOUT = STDOUT_FILENO;
+	    }
+	    if (FDSUSEROUT != STDOUT_FILENO) {
+		(void) close(FDSUSEROUT);
+		FDSUSEROUT = STDOUT_FILENO;
+	    }
+	    /* check to see whether there is a sort thread alive */
+	    if (Sorting_data(0) == SORT_TRUE) {
+		stop_sort_threads();
+	    }
+	    fprintf(stderr, "server: sort process has exited\n");
+	}
+    }   
+    
 /* check gui */
-      if (nogui == SORT_FALSE) {
-	    if (waitpid(gui_pid,&statusp,WNOHANG) == gui_pid) {
-		  nogui = SORT_TRUE;
-		  if (FDIN != STDIN_FILENO) {
-			(void) close(FDIN);
-			FDIN = STDIN_FILENO;
-		  }
-		  if (FDOUT != STDOUT_FILENO) {
-			(void) close(FDOUT);
-			FDDAT = FDOUT = STDOUT_FILENO;
-		  }
-		  if (statusp != 0) fprintf(stderr,
-			  "server: gui process has exited\n");
+    if (nogui == SORT_FALSE) {
+	if (waitpid(gui_pid,&statusp,WNOHANG) == gui_pid) {
+	    nogui = SORT_TRUE;
+	    if (FDIN != STDIN_FILENO) {
+		(void) close(FDIN);
+		FDIN = STDIN_FILENO;
 	    }
-      }
-      
+	    if (FDOUT != STDOUT_FILENO) {
+		(void) close(FDOUT);
+		FDDAT = FDOUT = STDOUT_FILENO;
+	    }
+	    if (statusp != 0)
+		fprintf(stderr, "server: gui process has exited\n");
+	}
+    }
+    
 /* check 1d display process */
-      if (graf_proc1_OK == SORT_TRUE) {
-	    if (waitpid(graf_1d_pid,&statusp,WNOHANG) == graf_1d_pid) {
-		  graf_proc1_OK = SORT_FALSE;
-		  fprintf(stderr,
-			  "server: 1d display process has exited\n");
-	    }
-      }
-      
+    if (graf_proc1_OK == SORT_TRUE) {
+	if (waitpid(graf_1d_pid,&statusp,WNOHANG) == graf_1d_pid) {
+	    graf_proc1_OK = SORT_FALSE;
+	    fprintf(stderr,
+		    "server: 1d display process has exited\n");
+	}
+    }
+    
 /* check 2d display process */
-      if (graf_proc2_OK == SORT_TRUE) {
-	    if (waitpid(graf_2d_pid,&statusp,WNOHANG)  == graf_2d_pid) {
-		  graf_proc2_OK = SORT_FALSE;
-		  fprintf(stderr,
-			  "server: 2d display process has exited\n");
-	    }
-      }
-
-      return;
+    if (graf_proc2_OK == SORT_TRUE) {
+	if (waitpid(graf_2d_pid,&statusp,WNOHANG)  == graf_2d_pid) {
+	    graf_proc2_OK = SORT_FALSE;
+	    fprintf(stderr,
+		    "server: 2d display process has exited\n");
+	}
+    }
 }
 
-/**************************************************************************************************/
+/************************************************************************/
 /*
  *  list of available commands and corresponding functions called
  */
@@ -939,48 +938,56 @@ static struct {
 } commands[] = {
       {"batch", batch_read, "batch <batch file name>"},
       {"clear", clear_spectra, "clear <all/1d/2d/selected>"},
-      {"close", close_sort_file, "close [tape/remote/disk]"},
+      {"close", close_sort_file, "close [tape/remote/disk/demon/pipe]"},
       {"debugsort",debugsort,"debugsort"},
-      {"display1d", display_1d, "display1d <#1d spectrum nos> + up to 3 others"},
+      {"display1d", display_1d,
+	  "display1d <#1d spectrum nos> + up to 3 others"},
       {"display2d", display_2d, "display2d <#2d spectrum nos>"},
-      {"displayaction", display_action, "displayaction <display/mstick>"},
+      {"displayaction", display_action,
+	  "displayaction <display/mstick/pkfind>"},
       {"editsort", editsort, "editsort <editor> <sort program name>"},
       {"eject", eject_func, "eject [access mode = r/w]"},
       {"end", end_batch, "end [batch]"},
       {"exit", exit_sunsort, "exit"},
       {"help", help_func, "help [command name]"},
       {"killsort", killsort, "killsort"},
-      {"load", load_spectra, "load <all/windows/variables/selected> <load directory> <format=sdb/eg/xy> [#add=1]"},
+      {"load", load_spectra, "load <all/windows/variables/selected> "
+          "<load directory> <format=sdb/eg/xy> [#add=1]"},
       {"loadsort", loadsort, "loadsort [-keep] [sort module name]"},
       {"loadspec", loadspec, "loadspec <spectra file>"},
-      {"makesort", makesort, "makesort <sort source name> [debug] [[-o sort name] other options...]"},
+      {"makesort", makesort, "makesort <sort source name> [debug] "
+          "[[-o sort name] other options...]"},
       {"newtape", newWtape, "newtape <volume name> <#drive nos>"},
-      {"open", open_sort_file, "open <tape/remote/disk> <sort file name>"},
-      {"overlay1d", overlay_1d, "overlay1d <#1d spectrum nos> + up to 3 others"},
+      {"open", open_sort_file,
+	  "open <tape/remote/disk/demon/pipe> <sort file name>"},
+      {"overlay1d", overlay_1d, 
+	  "overlay1d <#1d spectrum nos> + up to 3 others"},
       {"printsenv", print_sortenv, "printsenv"},
       {"printvars", print_vars, "printvars"},
+      {"processes", processes,
+	  "processes [number of processes (or 0 for automatic)]"},
       {"refresh", refresh_func, "refresh <#seconds>"},
       {"reset", reset_command, "reset <graphics/gui>"},
-      {"save", save_spectra, "save <all/windows/variables/selected> <save directory> <format=sdb/eg/xy> [#overwrite=1]"},
+      {"save", save_spectra, "save <all/windows/variables/selected> "
+          "<save directory> <format=sdb/eg/xy> [#overwrite=1]"},
       {"setsenv", set_sortenv, "setsenv <variable name> <new value>"},
       {"setwin", setwindow, "setwin <#window nos> on <#2d spectrum nos>"},
-      {"showwin", showwindow, "showwin <#window nos>"},
       {"sleep", sleep_func, "sleep <#seconds>"},
       {"sort", sort_data, "sort <#skip records> <#number of records to sort>"},
       {"status", status_func, "status"},
-      {"tapemount", tapemount, "tapemount <volume name or nonansi> <#drive nos> <access mode = r/w>"},
+      {"tapemount", tapemount, "tapemount <volume name or nonansi> "
+          "<#drive nos> <access mode = r/w>"},
       {"tapemove", tapemove, "tapemove <#nos files>"},
       {"tapeumount", tapeumount, "tapeumount <access mode = r/w>"},
       {"update", update_gui, "update GUI to reflect changes in variables"},
       {"var", change_var, "var <#variable nos> <#new value>"},
       {"vars", print_vars, "vars (same command as printvars)"},
-      {"viewwin", viewwindow, "viewwin <#window nos> <inside/outside> <#2d spectrum nos>"},
       {"wclose", close_filt_file, "wclose [tape/disk]"},
       {"wopen", open_filt_file, "wopen <tape/disk> <write file name>"},
       {"wrsort", write_sort, "wrsort <message to send to sort process>"},
       { NULL, NULL, NULL}
 };
-/**************************************************************************************************/
+/************************************************************************/
 int
 decode_command
 #if NeedFunctionPrototype
@@ -1050,7 +1057,7 @@ char     *opbuf;
     return(SORT_FAIL);
 }
 
-/**************************************************************************/
+/************************************************************************/
 /*
  *  display help information
  */
@@ -1139,6 +1146,11 @@ char     *reply;
 	fprintf(stderr, "Records read in so far = %d\n\n",
 		(int) *sorted_records); 
 	break;
+    case READING_PIPE:
+	pipestatus();
+	fprintf(stderr, "Records read in so far = %d\n\n",
+		(int) *sorted_records); 
+	break;
     default:
 	fprintf(stderr, "No read file open\n\n");
 	break;
@@ -1394,64 +1406,67 @@ makesort(
  *  kill off current sort process
  */
 int
-killsort(
+killsort
 #if NeedFunctionPrototype
-	   char *opt_str, char *reply)
+(char *opt_str, char *reply)
 #else
-      opt_str, reply)
-      char     *opt_str;
-      char     *reply;
+(opt_str, reply)
+char *opt_str;
+char *reply;
 #endif
 {
-      int   statusp;
-      int   reset = SORT_FALSE;
-      char  buf[BUFSIZ];
-      
-      if (DBX_val >= 5)
-	    fprintf(stderr,"server: killsort function called with args => %s\n",opt_str);
-
-      if (sscanf(opt_str,"%s",buf) == 1) {
-	    if (strncmp(buf,"reset",5) == 0)
-		  reset = SORT_TRUE;
-      }
-
+    int   statusp;
+    int   reset = SORT_FALSE;
+    char  buf[BUFSIZ];
+    
+    if (DBX_val >= 5)
+	fprintf(stderr,"server: killsort function called with args => %s\n",
+		opt_str);
+    
+    if (sscanf(opt_str,"%s",buf) == 1) {
+	if (strncmp(buf,"reset",5) == 0)
+	    reset = SORT_TRUE;
+    }
+    
+    kill_all_workers();
+    
 /* check to see if there is a sort process running .. if so kill it */      
-      if (sort_proc_OK == SORT_TRUE) {
-	    if (sort_pid > 0) {
-		  kill(sort_pid, SIGKILL);
-		  (void) waitpid(sort_pid,&statusp,0);
-	    }
-	    sort_proc_OK = SORT_FALSE;
-	    if (FDSIN != STDIN_FILENO) {
-		  (void) close(FDSIN);
-		  FDSIN = STDIN_FILENO;
-	    }
-	    if (FDSOUT != STDOUT_FILENO) {
-		  (void) close(FDSOUT);
-		  FDSOUT = STDOUT_FILENO;
-	    }
-	    if (FDSUSEROUT != STDOUT_FILENO) {
-		  (void) close(FDSUSEROUT);
-	          FDSUSEROUT = STDOUT_FILENO;
-	    }
-      }
-      else {
-	    if (reset == SORT_TRUE)
-		  (void) reset_all_buffers();
-	    sprintf(reply,"no sort process running!\n");
-	    return(SORT_FALSE);
-      }
+    if (sort_proc_OK == SORT_TRUE) {
+	if (sort_pid > 0) {
+	    kill(sort_pid, SIGKILL);
+	    (void) waitpid(sort_pid,&statusp,0);
+	}
+	sort_proc_OK = SORT_FALSE;
+	if (FDSIN != STDIN_FILENO) {
+	    (void) close(FDSIN);
+	    FDSIN = STDIN_FILENO;
+	}
+	if (FDSOUT != STDOUT_FILENO) {
+	    (void) close(FDSOUT);
+	    FDSOUT = STDOUT_FILENO;
+	}
+	if (FDSUSEROUT != STDOUT_FILENO) {
+	    (void) close(FDSUSEROUT);
+	    FDSUSEROUT = STDOUT_FILENO;
+	}
+    }
+    else {
+	if (reset == SORT_TRUE)
+	    (void) reset_all_buffers();
+	sprintf(reply,"no sort process running!\n");
+	return SORT_FALSE;
+    }
 
 /* check to see whether we are sorting ... if so reset buffers etc */      
-      if (Sorting_data(0) == SORT_TRUE) {
-	    stop_sort_threads();
-      }
-      else if (reset == SORT_TRUE) {
-	    (void) reset_all_buffers();
-      }
-      
-      sprintf(reply,"killsort suceeded\n");
-      return(SORT_TRUE);
+    if (Sorting_data(0) == SORT_TRUE) {
+	stop_sort_threads();
+    }
+    else if (reset == SORT_TRUE) {
+	(void) reset_all_buffers();
+    }
+    
+    sprintf(reply,"killsort suceeded\n");
+    return SORT_TRUE;
 }
 
 /*
@@ -1474,7 +1489,7 @@ char     *reply;
     char  *debugger = "dbxtool";
 #endif
 
-    /* Should really search path for this, but that's too muck like hard
+    /* Should really search path for this, but that's too much like hard
        work */
 
     char *workshop = "/opt/SUNWspro/bin/workshop";
