@@ -26,11 +26,13 @@
 #include "data_disk.h"
 #include "data_tape.h"
 #include "data_remote.h"
+#include "data_pipe.h"
 #include "demon.h"
+#include "version.h"
 
 /* local variables */
 static struct shared_data *sdat_ptr;
-static char               *data_file;
+static struct worker_data *wdat;
 
 static IOfunc       get_data_func = NULL;
 static IOfunc       put_data_func = NULL;
@@ -43,77 +45,173 @@ unsigned long      *filtered_records;
 sort_IO_t          *sort_io_data;
 dirs_IO_t          *dirs_io_data;
 
+static int worker_init(const char *data_file_dir)
+{
+    const char name[] = "/.worker_data";
+    char *worker_file;
+    int fd, i;
+
+    worker_file = (char *) malloc(strlen(data_file_dir)+strlen(name)+1);
+    if (worker_file == NULL) {
+	perror("worker_init");
+	fprintf(stderr, "server: failed to allocate memory for worker data "
+		"file name\n");
+	return -1;
+    }
+    sprintf(worker_file,"%s%s",data_file_dir,name);
+    
+    if ((fd = open(worker_file, O_RDWR | O_CREAT, 0600)) == -1)
+    {
+	perror("worker_init open");
+	free(worker_file);
+	return -1;
+    }
+
+    free(worker_file);
+
+    if (ftruncate(fd, sizeof(struct worker_data)) == -1)
+    {
+	perror("worker_init truncate");
+	close(fd);
+	return -1;
+    }
+
+    if ((caddr_t) (wdat = (struct worker_data *)
+		   mmap(NULL, sizeof(struct worker_data),
+			PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0))
+	== (caddr_t) -1)
+    {
+	perror("worker_init mmap");
+	close(fd);
+	return -1;
+    }
+    close(fd);
+
+    for(i = 0; i < MAX_WORKERS; i++)
+	wdat->worker_pid[i] = (pid_t) 0;
+
+    if (mutex_init(&wdat->worker_mutex, USYNC_PROCESS, NULL))
+    {
+	perror("worker_init mutex_init");
+	return -1;
+    }
+
+    return 0;
+}
+
+void kill_all_workers P((void))
+{
+    int i;
+
+    mutex_lock(&wdat->worker_mutex);
+    for(i = 0; i < MAX_WORKERS; i++)
+	if (wdat->worker_pid[i] != (pid_t) 0)
+	    kill(wdat->worker_pid[i], SIGKILL);
+    mutex_unlock(&wdat->worker_mutex);
+}
+
 /*
  *  create directory in which shared data file and spectra files shall reside
  */
 int
-create_shared_data(
+create_shared_data
 #if NeedFunctionPrototype
-		       char *data_file_dir)
+(const char *data_file_dir)
 #else
-      data_file_dir)
-      char *data_file_dir
+(data_file_dir)
+char *data_file_dir
 #endif
 {
-      char name[] = "/.shared.dat";
-      int filedes;
-      mode_t pmask;
-      mutex_t *mp;
-      cond_t  *cv;
-      int i;
+    const char name[] = "/.shared.dat";
+    char *data_file;
+    int filedes;
+    mode_t pmask;
+#ifndef USE_DATA_QUEUE
+    mutex_t *mp;
+    cond_t  *cv;
+    int i;
+#endif
       
 /* create name of shared data file */
-      data_file = (char *) malloc(strlen(data_file_dir)+strlen(name)+1);
-      if (data_file == NULL) {
-	    perror("create_shared_data");
-	    fprintf(stderr,"server: failed to allocate memory for shared data file name\n");
-	    return(-1);
-      }
-      sprintf(data_file,"%s%s",data_file_dir,name);
+    data_file = (char *) malloc(strlen(data_file_dir)+strlen(name)+1);
+    if (data_file == NULL) {
+	perror("create_shared_data");
+	fprintf(stderr, "server: failed to allocate memory for shared data "
+		"file name\n");
+	return -1;
+    }
+    sprintf(data_file,"%s%s",data_file_dir,name);
       
 /* set up shared resources */
-      pmask = umask(0077);
-      filedes = open(data_file, O_RDWR|O_CREAT,0600);
-      if (filedes == -1) {
-	    fprintf(stderr,"server: failed to create shared data file %s\n",data_file);
-	    return(-1);
-      }
-      (void) umask(pmask);
+    pmask = umask(0077);
+    filedes = open(data_file, O_RDWR|O_CREAT,0600);
+    if (filedes == -1) {
+	fprintf(stderr, "server: failed to create shared data file %s\n",
+		data_file);
+	free(data_file);
+	return -1;
+    }
+    (void) umask(pmask);
 
-      if (ftruncate(filedes,SHDATA_SIZE) == -1) {
-	    perror("ftruncate");
-	    return(-1);
-      }
+    free(data_file);
+
+    if (ftruncate(filedes,SHDATA_SIZE) == -1) {
+	perror("ftruncate");
+	return -1;
+    }
       
-      /*LINTED*/
-      if ( (caddr_t)(sdat_ptr = (struct shared_data *)mmap(0, SHDATA_SIZE, PROT_READ | PROT_WRITE,
-							MAP_SHARED, filedes, 0)) == (caddr_t) -1) {
-	    fprintf(stderr,"server: mmap error on shared data file\n");
-	    return(-1);
-      }
+    /*LINTED*/
+    if ((caddr_t) (sdat_ptr = (struct shared_data *)
+		   mmap(0, SHDATA_SIZE, PROT_READ | PROT_WRITE,
+			MAP_SHARED, filedes, 0)) == (caddr_t) -1) {
+	fprintf(stderr, "server: mmap error on shared data file\n");
+	return -1;
+    }
 
-      (void) close(filedes);
+    (void) close(filedes);
 
 /* set version information */
-      sdat_ptr->version = SUNSORT_VERSION;
+    sdat_ptr->version = SUNSORT_VERSION;
 
 /* set up other pointers to data structure */      
-      sort_io_data = &sdat_ptr->sort_io_data;
-      dirs_io_data = &sdat_ptr->dirs_io_data;
-      sorted_records = &sdat_ptr->in_records;
-      filtered_records = &sdat_ptr->out_records;
+    sort_io_data = &sdat_ptr->sort_io_data;
+    dirs_io_data = &sdat_ptr->dirs_io_data;
+    sorted_records = &sdat_ptr->in_records;
+    filtered_records = &sdat_ptr->out_records;
 
 /* initialize sorting state mutexes and conditional variables */
-      if (mutex_init(&sdat_ptr->mp_sorting, USYNC_PROCESS, NULL)) {
-	    perror("mutex sorting state initialization");
-	    return(-1);
-      }
-      if (cond_init(&sdat_ptr->cv_sorting, USYNC_PROCESS, NULL)) {
-	    perror("conditional variable sorting state initialization");
-	    return(-1);
-      }
-      sdat_ptr->sorting = SORTING_OFF;
+    if (mutex_init(&sdat_ptr->mp_sorting, USYNC_PROCESS, NULL)) {
+	perror("mutex sorting state initialization");
+	return -1;
+    }
+    if (cond_init(&sdat_ptr->cv_sorting, USYNC_PROCESS, NULL)) {
+	perror("conditional variable sorting state initialization");
+	return -1;
+    }
+    sdat_ptr->sorting = SORTING_OFF;
 
+#ifdef USE_DATA_QUEUE
+    if (queue_init(&sdat_ptr->read_full))
+    {
+	perror("read full queue");
+	return -1;
+    }
+    if (queue_init(&sdat_ptr->read_empty))
+    {
+	perror("read full queue");
+	return -1;
+    }
+    if (queue_init(&sdat_ptr->write_full))
+    {
+	perror("write full queue");
+	return -1;
+    }
+    if (queue_init(&sdat_ptr->write_empty))
+    {
+	perror("write full queue");
+	return -1;
+    }
+#else
 /* initialize read buffer mutexes and conditional variables */
       for(i=0; i< NOS_OF_RBUFS; i++) {
 	    mp = &sdat_ptr->read_buf[i].mp;
@@ -143,49 +241,89 @@ create_shared_data(
 	    }
 	    sdat_ptr->write_buf[i].state = EMPTY_BUF;
       }
-      
-      return(0);
+#endif
+
+      return worker_init(data_file_dir);
 }
 
 /*
  *  set the state of each read buffer to empty
  */
 int
-empty_R_buffers(
+empty_R_buffers
 #if NeedFunctionPrototype
-		  void )
+(void )
 #else
-      )
+()
 #endif
 {
-      data_buf_t *dptr;
-      int i;
-      
-      for(i=0; i< NOS_OF_RBUFS; i++) {
-	    dptr = &sdat_ptr->read_buf[i];
-	    if (mutex_trylock(&dptr->mp)) {
-		  perror("mutex read lock -- reset_buffers");
-		  return(-1);
+#ifdef USE_DATA_QUEUE      
+    int i;
+
+    if (queue_flush(&sdat_ptr->read_full))
+    {
+	perror("read full queue flush");
+	return -1;
+    }
+    if (queue_flush(&sdat_ptr->read_empty))
+    {
+	perror("read full queue flush");
+	return -1;
+    }
+
+    for(i = 0; i < NOS_OF_RBUFS; i++)
+	add_to_queue(&sdat_ptr->read_empty, i);
+    
+#else
+    data_buf_t *dptr;
+    int i;
+    
+    for(i=0; i< NOS_OF_RBUFS; i++) {
+	dptr = &sdat_ptr->read_buf[i];
+	if (mutex_trylock(&dptr->mp)) {
+	    perror("mutex read lock -- reset_buffers");
+		  return -1;
+	}
+	dptr->state = EMPTY_BUF;
+	if (mutex_unlock(&dptr->mp)) {
+	    perror("mutex read unlock-- reset_buffers");
+	    return -1;
 	    }
-	    dptr->state = EMPTY_BUF;
-	    if (mutex_unlock(&dptr->mp)) {
-		  perror("mutex read unlock-- reset_buffers");
-		  return(-1);
-	    }
-      }
-      return(0);
+    }
+#endif
+    return 0;
 }
 /*
  *  set the state of each write buffer to empty
  */
 int
-empty_W_buffers(
+empty_W_buffers
 #if NeedFunctionPrototype
-		  void )
+(void )
 #else
-      )
+()
 #endif
 {
+#ifdef USE_DATA_QUEUE      
+    int i;
+
+    if (queue_flush(&sdat_ptr->write_full))
+    {
+	perror("write full queue flush");
+	return -1;
+    }
+    if (queue_flush(&sdat_ptr->write_empty))
+    {
+	perror("write full queue flush");
+	return -1;
+    }
+
+    for(i = 0; i < NOS_OF_RBUFS; i++)
+    {
+	sdat_ptr->write_buf[i].data_size = MAX_DATA_SIZE;
+	add_to_queue(&sdat_ptr->write_empty, i);
+    }
+#else
       data_buf_t *dptr;
       int i;
 
@@ -201,101 +339,160 @@ empty_W_buffers(
 		  return(-1);
 	    }
       }
-      return(0);
+#endif
+      return 0;
 }
 
 /*
  *  set the state of each read buffer to empty
  */
 int
-diagnostic_R_buffers(
+diagnostic_R_buffers
 #if NeedFunctionPrototype
-		  void )
+(void)
 #else
-      )
+()
 #endif
 {
-      data_buf_t *dptr;
-      int i;
+    data_buf_t *dptr;
+    int i;
       
-      for(i=0; i< NOS_OF_RBUFS; i++) {
-	    dptr = &sdat_ptr->read_buf[i];
-	    if (mutex_trylock(&dptr->mp)) {
-		  perror("mutex read lock-- diagnostic_buffers");
-		  continue;
-	    }
-	    fprintf(stderr,"server: Read buffer %d in state %d\n", i, dptr->state);
-	    if (mutex_unlock(&dptr->mp)) {
-		  perror("mutex read unlock-- diagnostic_buffers");
-		  continue;
-	    }
-      }
-      return(0);
+#ifdef USE_DATA_QUEUE
+    fprintf(stderr, "Read empty queue: ");
+    queue_diagnostic(&sdat_ptr->read_empty);
+    fprintf(stderr, "Read full queue: ");
+    queue_diagnostic(&sdat_ptr->read_full);
+    fprintf(stderr, "Buffer status:");
+    for(i=0, dptr = sdat_ptr->read_buf; i < NOS_OF_RBUFS; dptr++, i++)
+	fprintf(stderr, " %d@%08x=%d", i, (unsigned long) dptr,
+		dptr->data_size);
+    putc('\n', stderr);
+#else
+    for(i=0; i< NOS_OF_RBUFS; i++) {
+	dptr = &sdat_ptr->read_buf[i];
+	if (mutex_trylock(&dptr->mp)) {
+	    perror("mutex read lock-- diagnostic_buffers");
+	    continue;
+	}
+	fprintf(stderr,"server: Read buffer %d in state %d\n", i, dptr->state);
+	if (mutex_unlock(&dptr->mp)) {
+	    perror("mutex read unlock-- diagnostic_buffers");
+	    continue;
+	}
+    }
+#endif
+    return 0;
 }
 
 /*
  * reset state of each shared buffer to EMPTY, re-inititialize locking variables
  */
 int
-reset_all_buffers(
+reset_all_buffers
 #if NeedFunctionPrototype
-		  void )
+(void)
 #else
-      )
+()
 #endif
 {
-      data_buf_t *dptr;
-      int i;
-
 /* reset read multexes and CV's */      
-      for(i=0; i< NOS_OF_RBUFS; i++) {
-	    dptr = &sdat_ptr->read_buf[i];
-	    if (mutex_destroy(&dptr->mp)) {
-		  perror("read mutex destroy");
-		  return(-1);
-	    }
-	    if (mutex_init(&dptr->mp, USYNC_PROCESS, NULL)) {
-		  perror("read mutex re-initialization");
-		  return(-1);
-	    }
-	    if (cond_destroy(&dptr->cv)) {
-		  perror("read conditional variable destroy");
-		  return(-1);
-	    }	
-	    if (cond_init(&dptr->cv, USYNC_PROCESS, NULL)) {
-		  perror("read conditional variable re-initialization");
-		  return(-1);
-	    }	    
-      }
-/* set state of all read buffers to empty */      
-      if (empty_R_buffers() == -1)
-	    return(-1);
+#ifdef USE_DATA_QUEUE
+    if (queue_destroy(&sdat_ptr->read_full))
+    {
+	perror("read full queue destroy");
+	return -1;
+    }
+    if (queue_destroy(&sdat_ptr->read_empty))
+    {
+	perror("read empty queue destroy");
+	return -1;
+    }
+    if (queue_init(&sdat_ptr->read_full))
+    {
+	perror("read full queue init");
+	return -1;
+    }
+    if (queue_init(&sdat_ptr->read_empty))
+    {
+	perror("read empty queue init");
+	return -1;
+    }
+#else
+    data_buf_t *dptr;
+    int i;
 
-/* reset write multexes and CV's */        
-      for(i=0; i< NOS_OF_WBUFS; i++) {
-	    dptr = &sdat_ptr->write_buf[i];
-	    if (mutex_destroy(&dptr->mp)) {
-		  perror("write mutex destroy");
-		  return(-1);
+    for(i=0; i< NOS_OF_RBUFS; i++) {
+	dptr = &sdat_ptr->read_buf[i];
+	if (mutex_destroy(&dptr->mp)) {
+	    perror("read mutex destroy");
+	    return(-1);
 	    }
-	    if (mutex_init(&dptr->mp, USYNC_PROCESS, NULL)) {
+	if (mutex_init(&dptr->mp, USYNC_PROCESS, NULL)) {
+	    perror("read mutex re-initialization");
+	    return(-1);
+	}
+	if (cond_destroy(&dptr->cv)) {
+	    perror("read conditional variable destroy");
+	    return(-1);
+	    }	
+	if (cond_init(&dptr->cv, USYNC_PROCESS, NULL)) {
+	    perror("read conditional variable re-initialization");
+	    return(-1);
+	}	    
+    }
+#endif
+/* set state of all read buffers to empty */      
+    if (empty_R_buffers() == -1)
+	return(-1);
+
+#ifdef USE_DATA_QUEUE
+    if (queue_destroy(&sdat_ptr->write_full))
+    {
+	perror("write full queue destroy");
+	return -1;
+    }
+    if (queue_destroy(&sdat_ptr->write_empty))
+    {
+	perror("write empty queue destroy");
+	return -1;
+    }
+    if (queue_init(&sdat_ptr->write_full))
+    {
+	perror("write full queue init");
+	return -1;
+    }
+    if (queue_init(&sdat_ptr->write_empty))
+    {
+	perror("write empty queue init");
+	return -1;
+    }
+#else
+/* reset write multexes and CV's */        
+    for(i=0; i< NOS_OF_WBUFS; i++) {
+	dptr = &sdat_ptr->write_buf[i];
+	if (mutex_destroy(&dptr->mp)) {
+	    perror("write mutex destroy");
+	    return(-1);
+	}
+	if (mutex_init(&dptr->mp, USYNC_PROCESS, NULL)) {
 		  perror("write mutex re-initialization");
 		  return(-1);
-	    }
-	    if (cond_destroy(&dptr->cv)) {
-		  perror("write conditional variable destroy");
-		  return(-1);
-	    }	
-	    if (cond_init(&dptr->cv, USYNC_PROCESS, NULL)) {
-		  perror("write conditional variable re-initialization");
-		  return(-1);
-	    }	    
-      }
-/* set state of all write buffers to empty */       
-      if (empty_W_buffers() == -1)
+	}
+	if (cond_destroy(&dptr->cv)) {
+	    perror("write conditional variable destroy");
 	    return(-1);
-      
-      return(0);
+	}	
+	if (cond_init(&dptr->cv, USYNC_PROCESS, NULL)) {
+	    perror("write conditional variable re-initialization");
+		  return(-1);
+	}	    
+    }
+#endif
+/* set state of all write buffers to empty */       
+    if (empty_W_buffers() == -1)
+	return(-1);
+    
+    return(0);
 }
 
 
@@ -461,6 +658,10 @@ void *data;
 	    thr_exit(NULL);
 	}
     }
+
+#ifdef USE_DATA_QUEUE
+    empty_R_buffers();
+#endif
       
     /* set sorting state to ON */
     (void) mutex_lock(&sdat_ptr->mp_sorting);
@@ -481,8 +682,31 @@ void *data;
      * note: a continue call before the very bottom of the loop does not
      * advance the buffer position.
      */
+#ifdef USE_DATA_QUEUE
+    for(records = 1; records <= sort_records && !Stop_interupt(0); )
+    {
+	to.tv_sec = time(NULL) + RTHREAD_WAIT;
+	if ((buffer_pos = take_from_queue(&sdat_ptr->read_empty, &to)) == -1)
+	    continue;
+
+	dptr = sdat_ptr->read_buf + buffer_pos;
+	bytes = (*get_data_func)(MAX_DATA_SIZE, (char *) dptr->data);
+	if (bytes <= 0) {
+	    fprintf(stderr, "read on data source returned %d (eof = 0) at "
+		    "record %d\n", bytes, records+skip_records);
+	    dptr->data_size = 0;
+	    add_to_queue(&sdat_ptr->read_full, buffer_pos);
+	    break;
+	}
+	dptr->data_size = bytes;
+	records++;
+	add_to_queue(&sdat_ptr->read_full, buffer_pos);
+    }
+
+#else
     for (records = 1 ; records <= sort_records && !Stop_interupt(0);
-	 dptr = &sdat_ptr->read_buf[buffer_pos]) {
+	 dptr = &sdat_ptr->read_buf[buffer_pos])
+    {
 
 	/* check state of next buffer in shared data storage */	    
 	(void) mutex_lock(&dptr->mp);
@@ -525,6 +749,7 @@ void *data;
 	
 	buffer_pos = (buffer_pos+1) % NOS_OF_RBUFS;
     }
+#endif
 
     /* exit prematurely from thread if requested to do so */     
     if (Stop_interupt(0) == SORT_EXIT)
@@ -535,6 +760,32 @@ void *data;
 	thr_exit(NULL);
     }
 
+#ifdef USE_DATA_QUEUE
+    if (DBX_val >= 5)
+	fprintf(stderr,"server: read thread EOD buffer %d after %d "
+		"records\n",buffer_pos,records-1);
+      
+    for(;;)
+    {
+	mutex_lock(&sdat_ptr->mp_sorting);
+	if (sdat_ptr->sorting  == SORTING_ON && Stop_interupt(0) != SORT_EXIT)
+	{
+	    mutex_unlock(&sdat_ptr->mp_sorting);
+	    to.tv_sec = time(NULL) + RTHREAD_WAIT;
+	    if ((buffer_pos = take_from_queue(&sdat_ptr->read_empty, &to))
+		!= -1)
+	    {
+		sdat_ptr->read_buf[buffer_pos].data_size = 0;
+		add_to_queue(&sdat_ptr->read_full, buffer_pos);
+	    }
+	}
+	else
+	{
+	    mutex_unlock(&sdat_ptr->mp_sorting);
+	    break;
+	}
+    }
+#else
     /* set current buffer to end of data state */
     (void) mutex_lock(&dptr->mp);
     while (dptr->state & (FULL_BUF|EMPTYING_BUF)) {
@@ -560,6 +811,7 @@ void *data;
 	if (Stop_interupt(0) == SORT_EXIT) 
 	    break;
     }
+#endif
     sdat_ptr->sorting = SORTING_OFF;
     (void) mutex_unlock(&sdat_ptr->mp_sorting);
     
@@ -581,80 +833,110 @@ void *data;
  */
 /*ARGSUSED*/
 static void *
-write_thread(
+write_thread
 #if NeedFunctionPrototype
-		  void *data)
+(void *data)
 #else
-      data)
-      void *data;
+(data)
+void *data;
 #endif
 {
-      data_buf_t *dptr;
-      int buffer_pos = 0;
-      int records;
-      int bytes;
-      timestruc_t to;
-      to.tv_nsec = 0;
+    data_buf_t *dptr;
+    int records, b;
+    int bytes;
+    timestruc_t to;
+    to.tv_nsec = 0;
+#ifndef USE_DATA_QUEUE    
+    int buffer_pos = 0;
+#endif
 
-      if (DBX_val >= 5)
-	    fprintf(stderr,"server: Starting write thread\n");
+    if (DBX_val >= 5)
+	fprintf(stderr,"server: Starting write thread\n");
 
-      for(records=0; Stop_interupt(0) != SORT_EXIT; ) {
-	    dptr = &sdat_ptr->write_buf[buffer_pos];
+#ifdef USE_DATA_QUEUE
+    empty_W_buffers();
+#endif
+      
+    for(records=0; Stop_interupt(0) != SORT_EXIT; )
+    {
+#ifdef USE_DATA_QUEUE
+	to.tv_sec = time(NULL) + WTHREAD_WAIT;
+	if ((b = take_from_queue(&sdat_ptr->write_full, &to)) == -1)
+	    continue;
+	dptr = sdat_ptr->write_buf + b;
 
+	if (dptr->data_size == 0)
+	    break;
+
+	bytes = (*put_data_func)(dptr->data_size, (char *) dptr->data);
+	if (bytes <= 0) {
+	    fprintf(stderr, "server: ERROR write returned %d at record %d\n",
+		    bytes, records);
+	    dptr->data_size = 0;
+	    add_to_queue(&sdat_ptr->write_empty, b);
+	    break;
+	}
+	sdat_ptr->out_records++;
+	records++;
+	dptr->data_size = MAX_DATA_SIZE;
+	add_to_queue(&sdat_ptr->write_empty, b);
+#else    
+	dptr = &sdat_ptr->write_buf[buffer_pos];
+	
 /* check state of next buffer in shared data storage */	    
-	    (void) mutex_lock(&dptr->mp);
-	    if (dptr->state == FULL_BUF) {
-		  dptr->state = EMPTYING_BUF;
-	    }
-	    else if (dptr->state == END_OF_DATA_BUF) {
-		  dptr->state = EMPTY_BUF;
-		  (void) mutex_unlock(&dptr->mp);
-		  break;
-	    }
-	    else {
-		  to.tv_sec = time(NULL) + WTHREAD_WAIT;
-		  (void) cond_timedwait(&dptr->cv, &dptr->mp, &to);
-		  (void) mutex_unlock(&dptr->mp);
-		  continue;
-	    } 
+	(void) mutex_lock(&dptr->mp);
+	if (dptr->state == FULL_BUF) {
+	    dptr->state = EMPTYING_BUF;
+	}
+	else if (dptr->state == END_OF_DATA_BUF) {
+	    dptr->state = EMPTY_BUF;
 	    (void) mutex_unlock(&dptr->mp);
-	    
+	    break;
+	}
+	else {
+	    to.tv_sec = time(NULL) + WTHREAD_WAIT;
+	    (void) cond_timedwait(&dptr->cv, &dptr->mp, &to);
+	    (void) mutex_unlock(&dptr->mp);
+	    continue;
+	} 
+	(void) mutex_unlock(&dptr->mp);
+	
 /* copy block from shared memory buffer to output device */
-	    bytes = (*put_data_func)(dptr->data_size, (char *) dptr->data);
-	    if (bytes <= 0) {
-		  fprintf(stderr,"server: ERROR write returned %d at record %d\n",bytes,records);
-		  (void) mutex_lock(&dptr->mp);
-		  dptr->state = BAD_BUFFER;
-		  (void) mutex_unlock(&dptr->mp);
-		  break;
-	    }
-    	    sdat_ptr->out_records++;
-	    records++;
-	    
-/* update state of next buffer in shared data storage */	  
+	bytes = (*put_data_func)(dptr->data_size, (char *) dptr->data);
+	if (bytes <= 0) {
+	    fprintf(stderr,"server: ERROR write returned %d at record %d\n",bytes,records);
 	    (void) mutex_lock(&dptr->mp);
-	    if (dptr->state == EMPTYING_BUF) {
-		  dptr->state = EMPTY_BUF;
-		  if (cond_signal(&dptr->cv)) {
-			perror("conditional variable signal");
-		  }
-	    }
-	    else {
-		  fprintf(stderr,"server: data buffer in wrong state, record %d\n",records);
-		  (void) mutex_unlock(&dptr->mp);
-		  continue;
-	    }
+	    dptr->state = BAD_BUFFER;
 	    (void) mutex_unlock(&dptr->mp);
-		  
-	    buffer_pos = (buffer_pos+1) % NOS_OF_WBUFS;
-      }
-
+	    break;
+	}
+	sdat_ptr->out_records++;
+	records++;
+	
+/* update state of next buffer in shared data storage */	  
+	(void) mutex_lock(&dptr->mp);
+	if (dptr->state == EMPTYING_BUF) {
+	    dptr->state = EMPTY_BUF;
+	    if (cond_signal(&dptr->cv)) {
+		perror("conditional variable signal");
+	    }
+	}
+	else {
+	    fprintf(stderr,"server: data buffer in wrong state, record %d\n",records);
+	    (void) mutex_unlock(&dptr->mp);
+	    continue;
+	}
+	(void) mutex_unlock(&dptr->mp);
+	
+	buffer_pos = (buffer_pos+1) % NOS_OF_WBUFS;
+#endif
+    }
+    
 /* exit write thread now */      
-       if (DBX_val >= 5)
-	    fprintf(stderr,"server: Ending write thread after %d records written out\n",records);
-      thr_exit(NULL);
-      return(NULL);
+    if (DBX_val >= 5)
+	fprintf(stderr,"server: Ending write thread after %d records written out\n",records);
+    thr_exit(NULL);
+    return(NULL);
 }
 
 /*
@@ -735,6 +1017,10 @@ sort_thread(
 	    get_data_func = demonread;
 	    fprintf(stderr,"server: reading from demon data feed ...\n");
       }
+      else if (io_ptr->IO_state & READING_PIPE) {
+	    get_data_func = piperead;
+	    fprintf(stderr,"server: reading from pipe ...\n");
+      }
       else {
 	    fprintf(stderr,"server: The function for reading data has not been internally specified !\n");
 	    fprintf(stderr,"server: This shouldn't happen ... help\n");
