@@ -1,7 +1,6 @@
 #ifndef SUNSORT_THREAD_h
 #define SUNSORT_THREAD_h
-
-#define SUNSORT_VERSION 1040698
+#define USE_DATA_QUEUE
 
 #include <unistd.h>
 #include <limits.h>
@@ -12,17 +11,19 @@
 #define SORTING_OFF 0
 #define SORTING_ON  1
 
-#define NOS_OF_RBUFS 4
-#define NOS_OF_WBUFS 4
+#define NOS_OF_RBUFS 8
+#define NOS_OF_WBUFS 8
 
 #define MAX_DATA_SIZE  16384
 
+#ifndef USE_DATA_QUEUE
 #define BAD_BUFFER        0x0
 #define END_OF_DATA_BUF   0x1
 #define EMPTY_BUF         0x2
 #define FILLING_BUF       0x4
 #define FULL_BUF          0x8
 #define EMPTYING_BUF      0x20
+#endif
 
 #define TYPE_var 0
 #define TYPE_1d  1
@@ -36,22 +37,23 @@
 
 #define tmp_PAGESIZE 4096
 
-
 typedef struct data_buf {
-      int      state;
-      mutex_t  mp;
-      cond_t   cv;
-      int      data_size;
-      char     data[MAX_DATA_SIZE];
+#ifndef USE_DATA_QUEUE
+    int      state;
+    mutex_t  mp;
+    cond_t   cv;
+#endif
+    int      data_size;
+    char     data[MAX_DATA_SIZE];
 } data_buf_t;
 
 typedef struct spec_info_entry {
-      char    name[NAME_SIZE];   /* spectrum title */
-      int     nos;               /* array position in look up table */
-      unsigned int  version;     /* info stating if entry has recently been modified */
-      int     size;              /* size in (int) */
-      int     win;               /* window number if 2d window ignored if 1d */
-      float   value;             /* value if variable */
+    char name[NAME_SIZE];/* spectrum title */
+    int nos;             /* array position in look up table */
+    unsigned int version;/* info stating if entry has recently been modified */
+    int size;            /* size in (int) */
+    int win;             /* window number if 2d window ignored if 1d */
+    float value;         /* value if variable */
 } spec_entry_t;
 
 typedef struct spec_1d {
@@ -98,26 +100,42 @@ typedef struct dirs_IO_data {
 	unsigned    IO_state;				/* whether loading or saving */
 } dirs_IO_t;
 
+#ifdef USE_DATA_QUEUE
+#include "data_queue.h"
+#endif
+
 struct shared_data {
-      int           version;
-      int           sorting;
-      mutex_t       mp_sorting;
-      cond_t        cv_sorting;
-      unsigned long in_records;
-      unsigned long out_records;
-      data_buf_t    read_buf[NOS_OF_RBUFS];
-      data_buf_t    write_buf[NOS_OF_WBUFS];
-      char          _pad[tmp_PAGESIZE];       /* pad space to put rest of data on new page */
-
-      /* should be read only data for all processes except server */
-      sort_IO_t     sort_io_data;
-      dirs_IO_t     dirs_io_data;
-      spec_entry_t  spec1d[TAB_SIZE_1D];
-      spec_entry_t  spec2d[TAB_SIZE_2D];
-      spec_entry_t  var[TAB_SIZE_VAR];
+    int version;
+    int sorting;
+#ifdef USE_DATA_QUEUE
+    struct data_buf_queue read_full;
+    struct data_buf_queue read_empty;
+    struct data_buf_queue write_full;
+    struct data_buf_queue write_empty;
+#endif
+    mutex_t mp_sorting;
+    cond_t cv_sorting;
+    unsigned long in_records;
+    unsigned long out_records;
+    data_buf_t read_buf[NOS_OF_RBUFS];
+    data_buf_t write_buf[NOS_OF_WBUFS];
+    char _pad[tmp_PAGESIZE]; /* pad space to put rest of data on new page */
+    
+    /* should be read only data for all processes except server */
+    sort_IO_t sort_io_data;
+    dirs_IO_t dirs_io_data;
+    spec_entry_t spec1d[TAB_SIZE_1D];
+    spec_entry_t spec2d[TAB_SIZE_2D];
+    spec_entry_t var[TAB_SIZE_VAR];
 };
 
-
 #define SHDATA_SIZE sizeof(struct shared_data)
 
+#define MAX_WORKERS 16
+
+struct worker_data {
+    mutex_t worker_mutex;
+    pid_t worker_pid[MAX_WORKERS];
+};
+
 #endif   /* endif ! SUNSORT_THREAD_h */
